@@ -1,46 +1,46 @@
-!= ޥɥ饤β
+!= コマンドライン引数の解析
 != Command line arguments parser
 !
 ! Authors::   Yasuhiro MORIKAWA
 ! Version::   $Id: dc_args.f90,v 1.2 2009-08-09 06:53:11 morikawa Exp $
-! Tag Name::  $Name: gtool5-20101228-1 $
+! Tag Name::  $Name:  $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
 
 module dc_args
   !
-  != ޥɥ饤β
+  != コマンドライン引数の解析
   != Command line arguments parser
   !
-  ! ޥɥ饤βϤԤޤ.
+  ! コマンドライン引数の解析を行います.
   !
-  ! ä, إץåɽ˴ؤʥ֥롼
-  ! ѰդƤޤ.
+  ! 加えて, ヘルプメッセージの表示に関して便利なサブルーチンも
+  ! 用意しています.
   !
   !== Tutorial
   !
-  ! * gtool5 ե塼ȥꥢ: 
-  !   {ޥɥ饤β}[link:../tutorial/dc_args.htm]
+  ! * gtool5 オフィシャルチュートリアル: 
+  !   {コマンドライン引数の解析}[link:../tutorial/dc_args.htm]
   !
   !== Procedures list
   !
-  ! DCArgsOpen     :: ¤ ARGS ѿν
-  ! DCArgsClose    :: ¤ ARGS ѿνλ
-  ! DCArgsGet      :: ޥɥ饤μ
-  ! DCArgsNumber   :: ޥɥ饤ο֤
-  ! DCArgsOption   :: ޥɥ饤ץ뤿
-  ! DCArgsDebug    :: ǥХåץμư
-  ! DCArgsHelp     :: إץץμư
-  ! DCArgsHelpMsg  :: إץå
-  ! DCArgsStrict   :: ̵ʥץ󤬻ꤵ줿˷ٹɽ褦
-  ! DCArgsPutLine  :: ¤ ARGS ѿƤ
+  ! DCArgsOpen     :: 構造型 ARGS 変数の初期化
+  ! DCArgsClose    :: 構造型 ARGS 変数の終了処理
+  ! DCArgsGet      :: コマンドライン引数の取得
+  ! DCArgsNumber   :: コマンドライン引数の数を返す
+  ! DCArgsOption   :: コマンドライン引数オプションを取得するための設定
+  ! DCArgsDebug    :: デバッグオプションの自動設定
+  ! DCArgsHelp     :: ヘルプオプションの自動設定
+  ! DCArgsHelpMsg  :: ヘルプメッセージの設定
+  ! DCArgsStrict   :: 無効なオプションが指定された時に警告を表示するよう設定
+  ! DCArgsPutLine  :: 構造型 ARGS 変数の内容を印字
   !
   !
   !== Usage
   !
-  ! ¤ ARGS ѿ, Open, Get Ѥ뤳Ȥ
-  ! ޥɥ饤뤳ȤǤޤ.
+  ! 構造型 ARGS の変数を定義し, Open, Get を利用することで
+  ! コマンドライン引数を取得することができます.
   !
   !     program dc_args_sample1
   !       use dc_types
@@ -64,9 +64,9 @@ module dc_args
   !       call DCArgsClose( arg = arg )  ! (inout)
   !     end program dc_args_sample1
   !
-  ! ˥ץꤷˤ, DCArgsOption ֥롼
-  ! ѤƤ. ץν񼰤˴ؤƤ DCArgsOption 
-  ! ֥ץν񼰡פ򻲾ȤƤ.
+  ! 引数にオプションを指定したい場合には, DCArgsOption サブルーチンを
+  ! 利用してください. オプションの書式に関しては DCArgsOption の
+  ! 「オプションの書式」を参照してください.
   !
   !     program dc_args_sample2
   !       use dc_types
@@ -104,69 +104,69 @@ module dc_args
   !       call DCArgsClose( arg = arg ) ! (inout)
   !     end program dc_args_sample2
   !
-  ! ޥɥ饤 '-h', '-H', '--help' ΤŤ줫Υץ
-  ! ꤹ뤳Ȥ, ץΰɸϤɽޤ.
+  ! コマンドライン引数に '-h', '-H', '--help' のいづれかのオプションを
+  ! 指定することで, オプションの一覧が標準出力に表示されます.
   !
-  ! إץåƤ򽼼¤ˤ DCArgsHelpMsg 
-  ! ȤƤ.
+  ! ヘルプメッセージの内容を充実させたい場合には DCArgsHelpMsg を
+  ! 参照してください.
   !
   !
   !== Note
   !
-  !=== ߴ
+  !=== 後方互換
   !
-  ! С 20071009 Ѳǽäʲμ³, 
-  ! ߴΤ, Ф餯ѲǽǤ. 
+  ! バージョン 20071009 以前に利用可能だった以下の手続きは, 
+  ! 後方互換のため, しばらくは利用可能です. 
   ! 
   ! * Open, Close, Option, PutLine, Debug, Help, HelpMsg, Strict, Get
   !   Number
   !
-  !=== dc_args ⥸塼ͳˤĤ
+  !=== dc_args モジュールを作成した理由について
   !
-  ! Fortran ѥΤۤȤɤˤ IARGC, GETARG Ȥä
-  ! ޥɥ饤ΤץबѰդƤ.
-  ! ץѤˤä, ޥɥ饤ΰ
-  ! ñ˼뤳ȤϴñǤ.
+  ! Fortran コンパイラのほとんどには IARGC, GETARG といった
+  ! コマンドライン引数取得のための副プログラムが用意されている.
+  ! これらの副プログラムの利用によって, コマンドラインの引数を
+  ! 単に取得することは簡単である.
   !
-  !  IARGC, GETARG λѤ˺ݤ, 2 Ĥۤݤ.
+  ! しかしこの IARGC, GETARG の使用に際し, 2 つほど面倒な点がある.
   !
-  ! 1 Ĥϥѥ¸ˤ IARGC, GETARG λͤΰ㤤Ǥ.
-  ! ץ Fortran ʤ˴ޤޤʤӥ롼
-  ! Ǥ뤿, ƤΥѥˤϤץ
-  ! ¸ߤΤ, ̯ͤ˰ۤʤ礬. (Υѥ
-  ! GETARG  1 ˤȰܤΰ뤬, 
-  ! Ť HITACHI Υѥ 2 ˤʤȰܤ
-  ! Ǥʤ, ʤ).  gtool5 饤֥Ǥ
-  ! Υѥ¸ۼ߷פԤäƤ.
-  ! dc_args ⥸塼Ѥݤˤ, Υѥ¸
-  ! ˤʤƤ褤. (ʤ, ѥ¸ºݤ
-  ! ۼƤΤ sysdep ⥸塼Ǥ).
+  ! 1 つはコンパイラ依存による IARGC, GETARG の仕様の違いである.
+  ! これらの副プログラムは Fortran 規格に含まれないサービスルーチン
+  ! であるため, たいていのコンパイラにはこの副プログラムは
+  ! 存在するものの, 仕様が微妙に異なる場合がある. (大抵のコンパイラは
+  ! GETARG の第一引数を 1 にすると一つ目の引数を取得するが, 
+  ! 古い HITACHI のコンパイラは第一引数を 2 にしないと一つ目の
+  ! 引数を取得できない, など). そこで gtool5 ライブラリでは
+  ! これらのコンパイラ依存性を吸収する設計を行っている.
+  ! dc_args モジュールを使用する際には, これらのコンパイラ依存は
+  ! 気にしなくてよい. (なお, コンパイラ依存性を実際に
+  ! 吸収しているのは sysdep モジュールである).
   !
-  ! 2 ܤ, ޥɥ饤ˤ륪ץ
-  ! (-h  --version ʤ) μ갷ؤǤ.
-  ! IARGC  GETARG ñ˰뤿ץǤ,
-  ! Perl  Ruby ʤɤΥ󥿥ץ꥿Τ褦,
-  ! ޥɥ饤˥ץ뤿
-  ! 饤֥ (Getopt  OptionParser ʤ) ѰդƤʤ.
-  ! dc_args ⥸塼, Fortran ץǤ⥪ץ
-  ! ڤ˰褦, ץ
-  ! Υǥ󥰤ǤǤˤ٤ץǤ.
+  ! 2 つ目は, コマンドライン引数におけるオプション引数
+  ! (-h や --version など) の取り扱いの不便さである.
+  ! IARGC や GETARG は単に引数を取得するための副プログラムであり,
+  ! Perl や Ruby などのインタプリタ言語のように,
+  ! コマンドライン引数にオプション引数を処理するための
+  ! ライブラリ (Getopt や OptionParser など) が用意されていない.
+  ! dc_args モジュールは, Fortran プログラムでもオプション引数を
+  ! 手軽に扱えるよう, オプション引数処理の
+  ! ためのコーディングをできるだけ簡素にするべく整備したプログラムである.
   !
-  ! ߷׻ۤ, {֥Ȼظץȸ Ruby}[http://www.ruby-lang.org/]
-  !  OptionParser[http://www.ruby-lang.org/ja/man/index.cgi?cmd=view;name=OptionParser]
-  ! 򿿻Ƥ, OptionParser 饹Υ֥Ȥ
-  ! ¤ ARGS , new (initialize) ᥽åɤ DCArgsOpen ֥롼,
-  ! on ᥽åɤ DCArgsOption ֥롼, parse ᥽åɤ DCArgsGet
-  ! ֥롼˸ΩƤƤ. ͤΰ㤤ˤͤ
-  ! ʤ˰ۤʤ뤬, ¤ ARGS ѿ򥪥֥Ȥ˸Ω,
-  ! ѿФƥ֥롼Ѥ뤳Ȥˤä
-  ! ֥Ȥؤ䥪֥ȤΰμԤȤǤ
-  ! OptionParser ƱͤǤ.
+  ! 設計思想は, {オブジェクト指向スクリプト言語 Ruby}[http://www.ruby-lang.org/]
+  ! の OptionParser[http://www.ruby-lang.org/ja/man/index.cgi?cmd=view;name=OptionParser]
+  ! を真似ており, OptionParser クラスのオブジェクトを
+  ! 構造型 ARGS に, new (initialize) メソッドを DCArgsOpen サブルーチンに,
+  ! on メソッドを DCArgsOption サブルーチンに, parse メソッドを DCArgsGet
+  ! サブルーチンに見立てている. 言語仕様の違いにより実装や仕様は
+  ! それなりに異なるが, 構造型 ARGS の変数をオブジェクトに見立て,
+  ! この変数に対してサブルーチンを作用させることによって
+  ! オブジェクトへの操作やオブジェクトからの引数情報の取得を行うという点では
+  ! OptionParser と同様である.
   !
-  ! ޤŪǽǤ뤬, dc_trace ⥸塼ȤϢȤޤƤ,
-  ! Debug ֥롼Ѥ뤳Ȥˤ (ˡϾ嵭), ƥ
-  ! ѥ뤹뤳Ȥʤ, ץμ¹Ԥκݤ "-D" ץĤ
-  ! ȤǥǥХååɽ⡼ɤѹ뤳ȤǤ.
+  ! おまけ的機能であるが, dc_trace モジュールとの連携も図られており,
+  ! Debug サブルーチンを使用することにより (使用法は上記参照), 再コン
+  ! パイルすることなく, プログラムの実行の際に "-D" オプションをつける
+  ! ことでデバッグメッセージを表示するモードに変更することもできる.
   !
 
   use dc_types, only : STRING
@@ -181,47 +181,47 @@ module dc_args
   public:: DCArgsNumber
 
   !-----------------------------------------------
-  ! ߴ
+  ! 後方互換用
   ! For backward compatibility
   public:: Open, Close, Option, PutLine, Debug, Help, HelpMsg, Strict, Get
   public:: Number
 
   type ARGS
     !
-    ! ޥɥ饤Ѥι¤ΤǤ.
-    ! ˤ DCArgsOpen , λˤ DCArgsClose Ѥޤ.
-    ! ޥɥ饤Ϳ, ץ 
-    ! DCArgsOption, DCArgsHelpMsg ֥롼ˤäͿ줿
-    ! Ǽޤ.
+    ! コマンドライン引数解析用の構造体です.
+    ! 初期化には DCArgsOpen を, 終了処理には DCArgsClose を用います.
+    ! コマンドライン引数に与えられる引数や, プログラム内で 
+    ! DCArgsOption, DCArgsHelpMsg サブルーチンによって与えられた情報を
+    ! 格納します.
     !
-    ! ܤȤ dc_args  Usage 򻲾Ȥ.
+    ! 詳しい使い方は dc_args の Usage を参照ください.
     !
     private
     type(OPT_ENTRY), pointer :: opt_table(:) => null()
-                              ! DCArgsOption ֥롼ǻꤵ
-                              ! ץΥꥹ
+                              ! DCArgsOption サブルーチンで指定される
+                              ! オプションのリスト
     logical :: initialized = .false.
     type(CMD_OPTS_INTERNAL), pointer :: cmd_opts_list(:) => null()
-                              ! ޥɥ饤Τ, ץ
-                              ! Ƽ̤ΤΤΥꥹ.
+                              ! コマンドライン引数のうち, オプションと
+                              ! して識別されるものののリスト.
     type(HASH) :: helpmsg
   end type ARGS
 
   type OPT_ENTRY
     character(STRING), pointer:: options(:) => null()
-                              ! ץ̾ꥹ
+                              ! オプション名リスト
     character(STRING) :: help_message
-                              ! إץå
+                              ! ヘルプメッセージ
     logical :: optvalue_flag
-                              ! ץ̵ͤͭ
+                              ! オプションの値の有無
   end type OPT_ENTRY
 
   type CMD_OPTS_INTERNAL
-    character(STRING) :: name  ! ץ̾
-    character(STRING) :: value ! 
+    character(STRING) :: name  ! オプション名
+    character(STRING) :: value ! 値
     logical:: flag_called = .false.
-                              ! Υץ̾ DCArgsOption ǸƤФ줿
-                              ! ɤȽ̤ե饰
+                              ! このオプション名が DCArgsOption で呼ばれたもの
+                              ! かどうかを判別するフラグ
   end type CMD_OPTS_INTERNAL
 
   interface DCArgsOpen
@@ -265,7 +265,7 @@ module dc_args
   end interface
 
   !-----------------------------------------------
-  ! ߴ
+  ! 後方互換用
   ! For backward compatibility
   interface Open
     module procedure DCArgsOpen0
@@ -309,40 +309,40 @@ module dc_args
 
 
   !-------------------------------------
-  ! BuildArgTable ꤵѿ
+  ! BuildArgTable で設定される変数
   character(STRING), allocatable, save:: argstr_table(:)
-                              ! . (ץ󤫤ɤʤ
-                              ! Ƚ̤ϹԤäƤʤ). BuildArgTable
-                              ! ꤵ.
+                              ! 全引数の内容. (オプションかどうかなど
+                              ! の判別は行っていない). BuildArgTable
+                              ! で設定される.
 
   integer, save:: argind_count = -1
-                              ! ο. BuildArgTable 
-                              ! ꤵ.
+                              ! 全引数の数. BuildArgTable で
+                              ! 設定される.
 
   !-------------------------------------
-  ! SortArgTable ꤵѿ
+  ! SortArgTable で設定される変数
   type(CMD_OPTS_INTERNAL), allocatable, save :: cmd_opts_list(:)
-                              ! ޥɥ饤Τ, ץ
-                              ! Ƽ̤ΤΤΥꥹ
-                              ! . SortArgTable ꤵ.
+                              ! コマンドライン引数のうち, オプションと
+                              ! して識別されるものののリス
+                              ! ト. SortArgTable で設定される.
 
   character(STRING), allocatable, save:: cmd_argv_list(:)
-                              ! ޥɥ饤Τ, ץ
-                              ! ϤʤΥꥹ. SortArgTable 
-                              ! ꤵ.
+                              ! コマンドライン引数のうち, オプションで
+                              ! はない引数のリスト. SortArgTable で設
+                              ! 定される.
 
 contains
 
   subroutine DCArgsOpen0(arg)
     !
-    ! ARGS ѿꤷޤ. 
+    ! ARGS 型の変数を初期設定します. 
     !
-    ! ARGS ѿѤݤˤϤޤΥ֥롼ˤä
-    ! ԤäƤ.
+    ! ARGS 型の変数を利用する際にはまずこのサブルーチンによって
+    ! 初期設定を行ってください.
     !
-    ! Υ֥롼, 겼ؤΥ֥롼 IARGC  GETARG
-    ! Ѥ줿ޥɥ饤ξ *arg*
-    ! ؤȳǼޤ.
+    ! このサブルーチンは, より下層のサブルーチン内で IARGC や GETARG
+    ! を用いて得られたコマンドライン引数の情報を引数 *arg*
+    ! へと格納します.
     !
     use dc_message, only: MessageNotify
     use dc_types, only: STRING
@@ -366,7 +366,7 @@ contains
 
   subroutine DCArgsClose0(arg)
     !
-    ! ARGS ѿνλԤޤ. 
+    ! ARGS 型の変数の終了処理を行います. 
     !
     use dc_hash, only: DCHashDelete
     implicit none
@@ -393,40 +393,40 @@ contains
 
   subroutine DCArgsOption0(arg, options, flag, value, help)
     !
-    ! ץϿȼԤޤ. 
+    ! オプション情報の登録と取得を行います. 
     !
-    ! ޥɥ饤Τ, *options* Ϳ륪ץ˴ؤ
-    !  *flag*  *value* ˼ޤ. *options* ޥɥ饤
-    ! ͿƤ *flag*  .true. , Ǥʤ 
-    ! .false. ֤ޤ. ץͤꤵ *value* 
-    ! ֤ͤޤ. ץΤͿƤʤˤ
-    ! *value* ˤ϶ʸ֤ޤ.
+    ! コマンドライン引数のうち, *options* に与えるオプションに関する情
+    ! 報を *flag* と *value* に取得します. *options* がコマンドライン
+    ! 引数に与えられていれば *flag* に .true. が, そうでない場合は 
+    ! .false. が返ります. オプションに値が指定される場合は *value* に
+    ! その値が返ります. オプション自体が与えられていない場合には
+    ! *value* には空文字が返ります.
     !
-    ! *help* ˤ *options* ˴ؤإץå *arg* 
-    ! Ͽޤ. ֥롼 DCArgsHelp 
-    ! Ѥݤ, ΥåϤޤ.
-    ! *value* ͿƤ뤫ɤǤΥåѲޤ.
+    ! *help* には *options* に関するヘルプメッセージを *arg* に
+    ! 登録します. サブルーチン DCArgsHelp を
+    ! 用いた際に, このメッセージが出力されます.
+    ! *value* を与えているかどうかでこのメッセージは変化します.
     !
-    !=== ץν
+    !=== オプションの書式
     !
-    ! ޥɥ饤Τ, ץȽꤵΤϰʲξǤ.
+    ! コマンドライン引数のうち, オプションと判定されるのは以下の場合です.
     !
-    ! * 1 ʸܤ '-' ξ. ξûץȤʤ, '-'
-    !   μΰʸΤߤץȤͭˤʤޤ.
+    ! * 1 文字目が '-' の場合. この場合は短いオプションとなり, '-'
+    !   の次の一文字のみがオプションとして有効になります.
     !
-    ! * 1-2ʸܤ '--' (ϥե 2 ʸ) ξ.
-    !   ξĹץȤʤ,
-    !   '--' ʹߤʸ󤬥ץȤͭˤʤޤ.
+    ! * 1-2文字目が '--' (ハイフン 2 文字) の場合.
+    !   この場合は長いオプションとなり,
+    !   '--' 以降の文字列がオプションとして有効になります.
     !
-    ! ץͤ, "=" ʸˤʤޤ.
+    ! オプションの値は, "=" よりも後ろの文字列になります.
     !
-    ! 
+    ! 例
     !
-    ! <b>ޥɥ饤</b>  :: <b>ץ̾,       </b>
-    ! -h                         ::    -h,           ̵
-    ! --help                     ::    --help,       ̵
+    ! <b>コマンドライン引数</b>  :: <b>オプション名, 値      </b>
+    ! -h                         ::    -h,           無し
+    ! --help                     ::    --help,       無し
     ! -D=6                       ::    -D,            6
-    ! -debug=                    ::    -d,           ̵
+    ! -debug=                    ::    -d,           無し
     ! --include=/usr             ::    --include,    /usr
     !
 
@@ -454,16 +454,16 @@ contains
     end if
 
     !-----------------------------------
-    ! ¤ ARGS ؤΥإץåѤξϿ
-    ! * ޤϥơ֥ arg % opt_table Ĺ.
+    ! 構造体 ARGS へのヘルプメッセージ用の情報登録
+    ! * まずはテーブル arg % opt_table を一つ広げる.
     !-----------------------------------
     if ( .not. associated( arg % opt_table ) ) then
-      ! 1 ĤΥץ
+      ! 1 つめのオプション指定
       !
       table_size = 0
       allocate(arg % opt_table(table_size + 1))
     else
-      ! 2 ĤʹߤΥץ
+      ! 2 つめ以降のオプション指定
       !
       table_size = size(arg % opt_table)
       allocate(local_tables(table_size))
@@ -474,7 +474,7 @@ contains
       deallocate(local_tables)
     end if
 
-    !----- ͤ -----
+    !----- 値の代入 -----
     allocate(arg % opt_table(table_size + 1) % options(options_size))
     arg % opt_table(table_size + 1) % options = options
     arg % opt_table(table_size + 1) % help_message = ''
@@ -484,7 +484,7 @@ contains
     arg % opt_table(table_size + 1) % optvalue_flag = present(value)
 
 
-    !----- options  -----
+    !----- options の正規化 -----
     do i = 1, options_size
       opt_full = arg % opt_table(table_size + 1) % options(i)
       if (DCOptionFormC(opt_full, opt_name, opt_value)) then
@@ -500,9 +500,9 @@ contains
       end if
     end do
 
-    ! arg % cmd_opts_list õ flag, value ؤ
-    ! ƤФ줿Τ˴ؤƤ arg % cmd_opts_list % flag_called 
-    ! .true. 
+    ! arg % cmd_opts_list 内の探査と flag, value への代入
+    ! 呼ばれたものに関しては arg % cmd_opts_list % flag_called を
+    ! .true. に
     do i = 1, options_size
       do j = 1, size(arg % cmd_opts_list)
         if (trim(arg % opt_table(table_size + 1) % options(i)) &
@@ -519,10 +519,10 @@ contains
 
   subroutine DCArgsDebug0(arg)
     !
-    ! ǥХåץμưԤޤ. 
+    ! デバッグオプションの自動設定を行います. 
     !
-    ! -D ⤷ --debug ꤵ줿, ưŪ
-    ! dc_trace#SetDebug ƤӽФ褦 *arg* ꤷޤ.
+    ! -D もしくは --debug が指定された際, 自動的に
+    ! dc_trace#SetDebug を呼び出すよう *arg* を設定します.
     !
     use dc_types, only: STRING
     use dc_string, only: StoA, StoI
@@ -554,19 +554,19 @@ contains
 
   subroutine DCArgsHelp0(arg, force)
     !
-    ! إץץμưԤޤ. 
+    ! ヘルプオプションの自動設定を行います. 
     !
-    ! -h, -H, --help ΤŤ줫ꤵ줿, ưŪ *arg* ꤵ줿
-    ! إץåȤɽ, ץλޤ.
-    ! §Ū, Υ֥롼 DCArgsOption, DCArgsDebug 
-    ! Υ֥롼Ƥǲ.
+    ! -h, -H, --help のいづれかが指定された際, 自動的に *arg* 内に設定された
+    ! 情報をヘルプメッセージとして表示した後, プログラムを終了させます.
+    ! 原則的に, このサブルーチンよりも前に DCArgsOption, DCArgsDebug 
+    ! のサブルーチンを呼んで下さい.
     !
-    ! *force*  .true. ꤵ, -H, --help ץͿ
-    ! ʤǤإץåɽ, ץλ
-    ! ޤ.
+    ! *force* に .true. が指定される場合, -H, --help オプションが与え
+    ! られない場合でもヘルプメッセージを表示した後, プログラムを終了さ
+    ! せます.
     !
-    ! إץåɽ, DCArgsOption, DCArgsHelpMsg
-    ! ֥롼ˤäղä뤳ȤǽǤ.
+    ! ヘルプメッセージに表示される情報は, DCArgsOption, DCArgsHelpMsg
+    ! サブルーチンによって付加することが可能です.
     !
     use dc_types, only: STRING, STDOUT
     use dc_string, only: StoA, StoI, Printf, Concat, JoinChar, UChar, LChar
@@ -661,15 +661,15 @@ contains
 
   subroutine DCArgsHelpMsg0(arg, category, msg)
     !
-    ! إץåɲäޤ. 
+    ! ヘルプメッセージを追加します. 
     !
-    ! ֥롼 DCArgsHelp Ѥݤ˽Ϥå
-    ! ղäޤ. *category*  +Title+, +Overview+, +Usage+ 
-    ! ꤵ줿Τ +Options+ ,
-    ! ʳΤΤϲɽޤ.
-    ! *msg* ˤϥåͿƤ.
+    ! サブルーチン DCArgsHelp を使用した際に出力されるメッセージを
+    ! 付加します. *category* に +Title+, +Overview+, +Usage+ が
+    ! 指定されたものは +Options+ よりも上部に,
+    ! それ以外のものは下部に表示されます.
+    ! *msg* にはメッセージを与えてください.
     !
-    !=== 
+    !=== 例
     !
     !     program dc_args_sample3
     !       use dc_types
@@ -721,9 +721,9 @@ contains
     !       call DCArgsClose( arg = arg )  ! (inout)
     !     program dc_args_sample3
     !
-    ! ޥɥ饤 '-h', '-H', '--help' ΤŤ줫Υץ
-    ! ꤹ뤳Ȥ, HelpMsg Ϳå, ץΰ
-    ! ɸϤɽޤ.
+    ! コマンドライン引数に '-h', '-H', '--help' のいづれかのオプション
+    ! を指定することで, HelpMsg で与えたメッセージと, オプションの一覧
+    ! が標準出力に表示されます.
     !
     use dc_hash, only: DCHashPut
     use dc_string, only: UChar
@@ -744,18 +744,18 @@ contains
 
   subroutine DCArgsStrict0(arg, severe)
     !
-    ! ץåԤޤ. 
+    ! オプションチェックを行います. 
     !
-    ! ޥɥ饤ΥץȤƻꤵ줿Τ,
-    ! DCArgsOption ֥롼ꤵƤʤΤ¸ߤ
-    ! ˤϷٹ֤ޤ. *severe*  .true. ꤹ
-    ! 顼֤ƽλޤ.
-    ! Υ֥롼Ƥ, DCArgsOption, DCArgsDebug, 
-    ! DCArgsHelp ֥롼ƤǤ.
+    ! コマンドライン引数のオプションとして指定されたものの内,
+    ! DCArgsOption サブルーチンで設定されていないものが存在する
+    ! 場合には警告を返します. *severe* に .true. を指定すると
+    ! エラーを返して終了します.
+    ! このサブルーチンを呼ぶ前に, DCArgsOption, DCArgsDebug, 
+    ! DCArgsHelp サブルーチンを呼んでください.
     !
-    ! ¤ ARGS ѿФƤΥ֥롼ŬѤƤ
-    ! Ȥ, ޥɥ饤ȤͿץ
-    ! ץबǧƤ뤫ɤå뤳ȤǤޤ.
+    ! 構造体 ARGS の変数に対してこのサブルーチンを適用しておく
+    ! ことで, コマンドライン引数として与えたオプションが正しく
+    ! プログラムが認識しているかどうかをチェックすることができます.
     !
     !
     use dc_types, only: STRING
@@ -787,11 +787,11 @@ contains
 
   subroutine DCArgsGet0(arg, argv)
     !
-    ! ޥɥ饤Τ, ץǤϤʤΤ
-    ! *argv* ֤ޤ.
+    ! コマンドライン引数のうち, オプションではないものを
+    ! *argv* に返します.
     !
-    ! *argv* ʸΥݥ󥿤Ǥ.
-    ! ȤͿˤɬ֤ͿƤ.
+    ! *argv* は文字型配列のポインタです.
+    ! 引数として与える場合には必ず空状態して与えてください.
     !
     use dc_types, only: STRING
     use dc_string, only: StoA, StoI, Printf, Concat, JoinChar
@@ -816,7 +816,7 @@ contains
 
   function DCArgsNumber0(arg) result(result)
     !
-    ! ޥɥ饤ȤͿ줿ο֤ޤ.
+    ! コマンドライン引数として与えられた引数の数を返します.
     !
     use dc_message, only: MessageNotify
     implicit none
@@ -833,7 +833,7 @@ contains
 
   subroutine DCArgsPutLine0(arg)
     !
-    ! *arg* ˴ؤɸϤɽޤ.
+    ! *arg* に関する情報を標準出力に表示します.
     !
     use dc_types, only: STDOUT
     use dc_string, only: Printf, JoinChar
@@ -876,22 +876,22 @@ contains
 
   subroutine PrintAutoLinefeed(unit, fmt, length, indent)
     !
-    ! ʸưԤƽϤޤ. 
-    ! Υ⥸塼Ѥ뤿Υ֥롼Ǥ.
+    ! 文字列を自動改行して出力します. 
+    ! このモジュール内部で用いるためのサブルーチンです.
     !
-    ! *fmt* Ϳ줿ʸϤʸ *length* (ꤵʤ 70)
-    ! ˲Ԥ, Ϥޤ. Ϥκ, *indent* ꤵƤ
-    ! ʸƬƽϤԤޤ.
-    ! ϥǥեȤɸϤȤʤޤ. *unit* ˽ֹ
-    ! ꤹ뤳ȤǽѹǤޤ.
+    ! *fmt* に与えられた文章を文字数 *length* (指定されない場合 70)
+    ! 以内に改行し, 出力します. 出力の際, *indent* が指定されていると
+    ! その文字列を行頭に挿入して出力を行います.
+    ! 出力先はデフォルトは標準出力となります. *unit* に出力装置番号
+    ! を設定することで出力先を変更できます.
     !
     use dc_types, only: STRING, STDOUT
     use dc_string, only: Split
     implicit none
     character(*), intent(in) :: fmt
-    integer,      intent(in), optional :: length ! ԤĹ
-    character(*), intent(in), optional :: indent ! ʸ
-    integer,      intent(in), optional :: unit   ! 
+    integer,      intent(in), optional :: length ! 一行の長さ
+    character(*), intent(in), optional :: indent ! 字下げ文字列
+    integer,      intent(in), optional :: unit   ! 出力装置
     character(STRING), pointer :: carray_tmp(:) => null()
     character(STRING) :: store_str
     integer, parameter :: default_len = 70
@@ -953,12 +953,12 @@ contains
 
   subroutine SortArgTable
     !
-    ! ΰʬΤΥ֥롼Ǥ. 
+    ! 内部向けの引数振り分けのためのサブルーチンです. 
     !
-    ! BuildArgTable ꤵ줿 argind_count, argstr_table 
-    ! Ѥ, cmd_argv_list, cmd_opts_list ꤷޤ.
+    ! BuildArgTable で設定された argind_count, argstr_table を
+    ! 用い, cmd_argv_list, cmd_opts_list を設定します.
     !
-    ! ˰٤ǤƤФƤ, ⤻˽λޤ.
+    ! 既に一度でも呼ばれている場合, 何もせずに終了します.
     !
     use dc_types, only: STRING
     implicit none
@@ -1001,12 +1001,12 @@ contains
 
   subroutine BuildArgTable
     !
-    ! ޥɥ饤Υ֥롼Ǥ. 
+    ! 内部向けコマンドライン引数処理のサブルーチンです. 
     !
-    ! ⥸塼 sysdep  sysdep#SysdepArgCount, sysdep#ArgGet
-    ! ƤӽФ, Ƥ argind_count  argstr_table ˳Ǽޤ.
+    ! モジュール sysdep の sysdep#SysdepArgCount, sysdep#ArgGet
+    ! を呼び出し, その内容を argind_count と argstr_table に格納します.
     !
-    ! ˰٤ǤƤФƤ, ⤻˽λޤ.
+    ! 既に一度でも呼ばれている場合, 何もせずに終了します.
     !
     use sysdep, only: SysdepArgCount, SysdepArgGet
     use dc_types, only: STRING
@@ -1032,32 +1032,32 @@ contains
 
   function DCOptionFormC(argument, name, value) result(result)
     !
-    ! ȤƤ줿ʸ *argument* ϤȤ,
-    ! 줬ץʤΤǤʤΤȽ̤, ⤷
-    ! ץȽ̤ˤͤ .true. ֤,
-    ! name ˥ץ̾, *value* ˤ֤ͤ.
-    ! ץͤղäʤ *value* ˤ϶֤.
+    ! 引数としてで得られた文字列を *argument* に渡すことで,
+    ! それがオプションなのかそうでないのかを判別し, もしも
+    ! オプションと判別した場合には戻り値に .true. を返し,
+    ! name にオプション名, *value* にその値を返す.
+    ! オプションに値が付加されない場合は *value* には空白を返す.
     !
-    ! ץǤϤʤͤ .false. ֤,
-    ! *name*, *value* ˤ϶֤.
+    ! オプションではない場合は戻り値に .false. を返し,
+    ! *name*, *value* には空白を返す.
     !
-    ! ץȽꤵΤϰʲξǤ.
+    ! オプションと判定されるのは以下の場合です.
     !
-    ! * ʸܤ '-' ξ. ξûץȤʤ, '-'
-    !   μΰʸΤߤץȤͭˤʤޤ.
+    ! * 一文字目が '-' の場合. この場合は短いオプションとなり, '-'
+    !   の次の一文字のみがオプションとして有効になります.
     !
-    ! * 1-2ʸܤ '--' ξ. ξĹץȤʤ,
-    !   '--' ʹߤʸ󤬥ץȤͭˤʤޤ.
+    ! * 1-2文字目が '--' の場合. この場合は長いオプションとなり,
+    !   '--' 以降の文字列がオプションとして有効になります.
     !
-    ! ץͤ, "=" ʸˤʤޤ.
+    ! オプションの値は, "=" よりも後ろの文字列になります.
     !
-    !=== 
+    !=== 例
     !
-    ! *argument*    :: <b>name,      value, ֤</b>
-    ! arg           ::    ,      ,  .false.
-    ! -O            ::    -O,        ,  .true.
-    ! -debug        ::    -d,        ,  .true.
-    ! --debug       ::    --debug,   ,  .true.
+    ! *argument*    :: <b>name,      value, 返り値</b>
+    ! arg           ::    空白,      空白,  .false.
+    ! -O            ::    -O,        空白,  .true.
+    ! -debug        ::    -d,        空白,  .true.
+    ! --debug       ::    --debug,   空白,  .true.
     ! -I=/usr       ::    -I,        /usr,  .true.
     ! --include=/usr::    --include, /usr,  .true.
     !
