@@ -1,37 +1,37 @@
-!= 顼 
+!= エラー処理
 !
 != Error handling
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
 ! Version::   $Id: dc_error.f90,v 1.3 2009-10-03 14:53:46 morikawa Exp $
-! Tag Name::  $Name: gtool5-20101228-1 $
+! Tag Name::  $Name:  $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
 module dc_error
   !
-  != 顼ѥ⥸塼
+  != エラー処理用モジュール
   !
   != Error handling module
   !
   ! <b>Note that Japanese and English are described in parallel.</b>
   !
-  ! ץʤɬ顼μ갷Τ˵ꤹ٤ΤǤ
-  ! 顼ȤʤؤϤŬڤǤȤ
-  ! Ԥư򤹤뤳ȤǤʤȤä֤ؤޤ
+  ! プログラムの部品は必ずエラーの取り扱いを明確に規定すべきものです。
+  ! エラーとは当該部品への入力が不適切であるとか、
+  ! 期待される動作をすることができないといった事態を指します。
   !
-  ! gtool5 饤֥꤬桼󶡤³
-  ! (³Ȥϥ֥롼ޤϴؿ) ϤۤȤɤξ硢
-  ! ʲ 2 ĤΤ줫ǸƤӽФ˥顼𤷤ޤ
+  ! gtool5 ライブラリがユーザに提供する手続
+  ! (手続とはサブルーチンまたは関数の総称) はほとんどの場合、
+  ! 以下の 2 つの方式のいずれかで呼び出し元にエラーを報告します。
   !
-  ! * 顼ȯŬڤʥåɽƥץཪλ
-  ! * ξάǤ *err* Ϳ줿ϡ
-  !   顼ˤϤ <tt>.true.</tt> ˤޤ
-  !   err ά줿ϾƱ
+  ! * エラーが発生すると適切なメッセージを表示してプログラム終了
+  ! * 論理型の省略できる引数 *err* が与えられた場合は、
+  !   エラー時にはそれを <tt>.true.</tt> にします。
+  !   err が省略された場合は上に同じ。
   !
-  ! νϤ٤ *dc_error* ⥸塼 *StoreError*
-  ! ֥롼ǹԤäƤޤѻͤʤɤ˴ؤƤ *StoreError*
-  ! 򻲾ȤƤ
+  ! これらの処理はすべて *dc_error* モジュールの *StoreError*
+  ! サブルーチンで行っています。引用仕様などに関しては *StoreError*
+  ! を参照してください。
   !
   !
   ! Error handling about parts of programs should be regulated definitely.
@@ -42,211 +42,211 @@ module dc_error
   ! provided to users by gtool5 library almost report error to invoker
   ! in the following two manner.
   !
-  ! * When error occurs, the program display appropriate messages and 
+  ! * When error occurs, the program display appropriate messages and
   !   aborts.
   ! * If logical optional argument *err* is given, the argument *err* become
-  !   <tt>.true.</tt> when error occurs. If *err* is abbreviated, 
+  !   <tt>.true.</tt> when error occurs. If *err* is abbreviated,
   !   the operation is same as above.
   !
   ! *StoreError* subroutine in *dc_error* module handle above all operations.
   ! See *StoreError* about the interfase of it.
   !
   !
-  !== 顼ɰ
+  !== エラーコード一覧
   !== Error code list
   !
-  ! gtool5 饤֥˥ɤɲäץޤŬڤ
-  ! 顼ɤ *StoreError* ƤӽФ褦ˤʤФʤޤ
-  ! ǡ 顼ɤɬפ뤫ɤ
-  ! Ƚꤹ뤿ˡ 顼ɤͤбå
-  ! ʲ˰ޤ
-  ! 顼ɥˡ˥åѤ뤿ˤϡ
-  ! <b><tt>NF_E</tt></b> ǻϤޤ̾ˤĤƤ netcdf_f77
-  ! ⥸塼Ѥ뤫 include 'netcdf.inc' ԤʸԤϿ侩ޤˡ
+  ! gtool5 ライブラリにコードを追加するプログラマは適切な
+  ! エラーコードで *StoreError* を呼び出すようにしなければなりません。
+  ! そこで、 新しいエラーコードを定義する必要があるかどうかを
+  ! 判定するために、 エラーコードの値と対応するメッセージを
+  ! 以下に一覧します。
+  ! エラーコードニーモニックを使用するためには、
+  ! <b><tt>NF_E</tt></b> で始まる名前については netcdf_f77
+  ! モジュールを引用するか include 'netcdf.inc' を行い（後者は推奨しません）、
   ! <b><tt>GT_E</tt></b>, <b><tt>DC_E</tt></b>, <b><tt>HST_E</tt></b>
-  ! ǻϤޤ̾ˤĤƤ dc_error ⥸塼ѤƤ
-  ! ޤ <b><tt>USR_ERRNO</tt></b> ֤꾮ͤϡ
-  ! ơΥ桼Ŭ顼ɤ
-  ! Ѥ뤿˶Ƥޤ
+  ! で始まる名前については dc_error モジュールを引用してください。
+  ! また <b><tt>USR_ERRNO</tt></b> 番より小さい値は、
+  ! 各々のユーザが適宜エラーコードを
+  ! 定義して利用するために空けてあります。
   !
-  ! 顼ǤϤʤ֤ɽ󥨥顼ɤ *DC_NOERR* Ǥ
+  ! エラーではない状態を表す非エラーコードは *DC_NOERR* です。
   !
-  ! 顼ɤοͤߤΤϡʥ顼ɤ
-  ! Ƥݤλؿˤ򼨤Ǥ
-  ! ɤˤϥ顼ɤˡ˥åͿ٤Ǥꡢ
-  ! ͤϡɥɤ뤳Ȥϸ˿ǲ
+  ! エラーコードの数値の欄を設けたのは、新たなエラーコードを
+  ! 割り当てる際の指針を示すためです。
+  ! ソースコードにはエラーコードをニーモニックで与えるべきであり、
+  ! 数値をハードコードすることは厳に慎んで下さい。
   !
   !
-  ! Programmers who add codes to gtool5 library must call 
-  ! *StoreError* with appropriate error code. 
-  ! And so values of error code and corresponding messages are listed 
-  ! as follows to figure out if a new error code is needed to declared. 
-  ! To use error codes mnemonic, 
-  ! require "netcdf_f77" module or include "netcdf.inc" (deprecated) 
-  ! about error codes with prefix <b><tt>NF_E</tt></b>, or 
-  ! require "dc_error" module 
-  ! about error codes with prefix <b><tt>GT_E</tt></b> and 
-  ! <b><tt>DC_E</tt></b> and <b><tt>HST_E</tt></b>. 
-  ! Error codes smaller than <b><tt>USR_ERRNO</tt></b> are saved 
+  ! Programmers who add codes to gtool5 library must call
+  ! *StoreError* with appropriate error code.
+  ! And so values of error code and corresponding messages are listed
+  ! as follows to figure out if a new error code is needed to declared.
+  ! To use error codes mnemonic,
+  ! require "netcdf_f77" module or include "netcdf.inc" (deprecated)
+  ! about error codes with prefix <b><tt>NF_E</tt></b>, or
+  ! require "dc_error" module
+  ! about error codes with prefix <b><tt>GT_E</tt></b> and
+  ! <b><tt>DC_E</tt></b> and <b><tt>HST_E</tt></b>.
+  ! Error codes smaller than <b><tt>USR_ERRNO</tt></b> are saved
   ! as user-defined error codes.
   !
-  ! Non error code that indicates normal (error-free) situation is 
+  ! Non error code that indicates normal (error-free) situation is
   ! *DC_NOERR*.
   !
-  ! List of numerical values of error codes 
-  ! issues a guideline about declaration of new error codes. 
+  ! List of numerical values of error codes
+  ! issues a guideline about declaration of new error codes.
   ! Give not numerical value but mnemonic of error code to source code.
   !
-  !=== Ѥʤ
+  !=== 利用しないコード
   !=== Unused codes
   !
-  ! ͤϥ顼ɤȤƻѤޤ
+  ! 正の整数値はエラーコードとして使用しません。
   !
-  ! NetCDF 饤֥ libc Υ顼 errno ֤ǽꡢ
-  ! errno οͤˤϰܿʤᡢƤͤ errno
-  ! λͤΤͽ󤵤Ƥ٤Ǥ
+  ! NetCDF ライブラリは libc のエラーコード errno を返す可能性があり、
+  ! errno の数値には移植性がないため、全ての正の整数値は errno
+  ! の仕様のために予約されているべきだからです。
   !
   ! Positive integer is not used as error codes.
   !
-  ! NetCDF library might return "libc" error code "error". 
-  ! Numerical value of "errno" is no portable, so positive integer 
+  ! NetCDF library might return "libc" error code "error".
+  ! Numerical value of "errno" is no portable, so positive integer
   ! should be reserved for "errno".
   !
-  !=== 󥨥顼
+  !=== 非エラーコード
   !=== Non error code
   !
-  ! ʲ󥨥顼ɤ˴ؤƤ dc_error ⥸塼Ѥ뤳Ȥ
-  ! ѤƤ
+  ! 以下の非エラーコードに関しては dc_error モジュールを引用することで
+  ! 利用してください。
   !
-  ! Use following non error code by refering this "dc_error" module. 
+  ! Use following non error code by refering this "dc_error" module.
   !
-  ! <b>. Number</b> :: <b>  [ ˡ˥å. Mnemonic ]</b>
+  ! <b>数値. Number</b> :: <b>  [ ニーモニック. Mnemonic ]</b>
   !
   ! 0       :: [ <b>DC_NOERR       </b> ]
   !
   !
-  !=== netCDF ˴ؤ륨顼
+  !=== netCDF に関するエラーコード
   !=== Error codes for netCDF
   !
-  ! ʲΥ顼ɤ˴ؤƤ netcdf_f77 ⥸塼Ѥ뤳Ȥ
-  ! ѤƤ
+  ! 以下のエラーコードに関しては netcdf_f77 モジュールを引用することで
+  ! 利用してください。
   !
-  ! Use following error codes by refering this "netcdf_f77" module. 
+  ! Use following error codes by refering this "netcdf_f77" module.
   !
-  ! <b>. Number</b> :: <b>  [ ˡ˥å. Mnemonic ] 顼å. Error message</b>
+  ! <b>数値. Number</b> :: <b>  [ ニーモニック. Mnemonic ] エラーメッセージ. Error message</b>
   !
   ! 0       :: [ <b>NF_NOERR       </b> ]
-  !            <b></b> :: No Error  (󥨥顼ɤǤ)
+  !            <b></b> :: No Error  (非エラーコードです)
   !
   ! -33     :: [ <b>NF_EBADID      </b> ]
   !            <b></b> :: Not a netCDF id:
   !
-  ! -34     :: [ <b>NF_ENFILE      </b> ] 
+  ! -34     :: [ <b>NF_ENFILE      </b> ]
   !            <b></b> :: Too many netCDF files open:
   !
-  ! -35     :: [ <b>NF_EEXIST      </b> ] 
+  ! -35     :: [ <b>NF_EEXIST      </b> ]
   !            <b></b> :: netCDF file exists && NC_NOCLOBBER:
   !
-  ! -36     :: [ <b>NF_EINVAL      </b> ] 
+  ! -36     :: [ <b>NF_EINVAL      </b> ]
   !            <b></b> :: Invalid argument:
   !
-  ! -37     :: [ <b>NF_EPERM       </b> ] 
+  ! -37     :: [ <b>NF_EPERM       </b> ]
   !            <b></b> :: Write to read only:
   !
-  ! -38     :: [ <b>NF_ENOTINDEFINE</b> ] 
+  ! -38     :: [ <b>NF_ENOTINDEFINE</b> ]
   !            <b></b> :: Operation not allowed in data mode
   !
-  ! -39     :: [ <b>NF_EINDEFINE   </b> ] 
+  ! -39     :: [ <b>NF_EINDEFINE   </b> ]
   !            <b></b> :: Operation not allowed in define mode
   !
-  ! -40     :: [ <b>NF_EINVALCOORDS</b> ] 
+  ! -40     :: [ <b>NF_EINVALCOORDS</b> ]
   !            <b></b> :: Index exceeds dimension bound
   !
-  ! -41     :: [ <b>NF_EMAXDIMS    </b> ] 
+  ! -41     :: [ <b>NF_EMAXDIMS    </b> ]
   !            <b></b> :: NF_MAX_DIMS exceeded
   !
-  ! -42     :: [ <b>NF_ENAMEINUSE  </b> ] 
+  ! -42     :: [ <b>NF_ENAMEINUSE  </b> ]
   !            <b></b> :: String match to name in use
   !
-  ! -43     :: [ <b>NF_ENOTATT     </b> ] 
+  ! -43     :: [ <b>NF_ENOTATT     </b> ]
   !            <b></b> :: Attribute not found
   !
-  ! -44     :: [ <b>NF_EMAXATTS    </b> ] 
+  ! -44     :: [ <b>NF_EMAXATTS    </b> ]
   !            <b></b> :: NC_MAX_ATTRS exceeded
   !
-  ! -45     :: [ <b>NF_EBADTYPE    </b> ] 
+  ! -45     :: [ <b>NF_EBADTYPE    </b> ]
   !            <b></b> :: Not a netCDF data type or _FillValue type mismatch
   !
-  ! -46     :: [ <b>NF_EBADDIM     </b> ] 
+  ! -46     :: [ <b>NF_EBADDIM     </b> ]
   !            <b></b> :: Invalid dimension id or name
   !
-  ! -47     :: [ <b>NF_EUNLIMPOS   </b> ] 
+  ! -47     :: [ <b>NF_EUNLIMPOS   </b> ]
   !            <b></b> :: NC_UNLIMITED in the wrong index
   !
-  ! -48     :: [ <b>NF_EMAXVARS    </b> ] 
+  ! -48     :: [ <b>NF_EMAXVARS    </b> ]
   !            <b></b> :: NF_MAX_VARS exceeded
   !
-  ! -49     :: [ <b>NF_ENOTVAR     </b> ] 
+  ! -49     :: [ <b>NF_ENOTVAR     </b> ]
   !            <b></b> :: Variable not found
   !
-  ! -50     :: [ <b>NF_EGLOBAL     </b> ] 
+  ! -50     :: [ <b>NF_EGLOBAL     </b> ]
   !            <b></b> :: Action prohibited on NC_GLOBAL varid
   !
-  ! -51     :: [ <b>NF_ENOTNC      </b> ] 
+  ! -51     :: [ <b>NF_ENOTNC      </b> ]
   !            <b></b> :: Not a netCDF file
   !
-  ! -52     :: [ <b>NF_ESTS        </b> ] 
+  ! -52     :: [ <b>NF_ESTS        </b> ]
   !            <b></b> :: In Fortran, string too short
   !
-  ! -53     :: [ <b>NF_EMAXNAME    </b> ] 
+  ! -53     :: [ <b>NF_EMAXNAME    </b> ]
   !            <b></b> :: NC_MAX_NAME exceeded
   !
-  ! -54     :: [ <b>NF_EUNLIMIT    </b> ] 
+  ! -54     :: [ <b>NF_EUNLIMIT    </b> ]
   !            <b></b> :: NC_UNLIMITED size already in use
   !
-  ! -55     :: [ <b>NF_ENORECVARS  </b> ] 
+  ! -55     :: [ <b>NF_ENORECVARS  </b> ]
   !            <b></b> :: NC_rec op when there are no record vars
   !
-  ! -56     :: [ <b>NF_ECHAR       </b> ] 
+  ! -56     :: [ <b>NF_ECHAR       </b> ]
   !            <b></b> :: Attempt to convert between text & numbers
   !
-  ! -57     :: [ <b>NF_EEDGE       </b> ] 
+  ! -57     :: [ <b>NF_EEDGE       </b> ]
   !            <b></b> :: Edge+start exceeds dimension bound
   !
-  ! -58     :: [ <b>NF_ESTRIDE     </b> ] 
+  ! -58     :: [ <b>NF_ESTRIDE     </b> ]
   !            <b></b> :: Illegal stride
   !
-  ! -59     :: [ <b>NF_EBADNAME    </b> ] 
+  ! -59     :: [ <b>NF_EBADNAME    </b> ]
   !            <b></b> :: Attribute or variable name contains illegal characters
   !
-  ! -60     :: [ <b>NF_ERANGE      </b> ] 
+  ! -60     :: [ <b>NF_ERANGE      </b> ]
   !            <b></b> :: Numeric conversion not representable
   !
-  ! -61     :: [ <b>NF_ENOMEM      </b> ] 
+  ! -61     :: [ <b>NF_ENOMEM      </b> ]
   !            <b></b> :: Memory allocation (malloc) failure
   !
-  ! -62     :: [ <b>NF_EVARSIZE      </b> ] 
+  ! -62     :: [ <b>NF_EVARSIZE      </b> ]
   !            <b></b> :: One or more variable sizes violate format constraints
   !
-  ! -63     :: [ <b>NF_EDIMSIZE      </b> ] 
+  ! -63     :: [ <b>NF_EDIMSIZE      </b> ]
   !            <b></b> :: Invalid dimension size
   !
-  ! -64     :: [ <b>NF_ETRUNC      </b> ] 
+  ! -64     :: [ <b>NF_ETRUNC      </b> ]
   !            <b></b> :: File likely truncated or possibly corrupted
   !
-  ! -62-99:: <b>               </b>
-  !            <b></b> :: ( netCDF γĥΤ gtool5 ͽΰ.
+  ! -62〜-99:: <b>               </b>
+  !            <b></b> :: (将来の netCDF の拡張のための gtool5 の予約領域.
   !                       Reserved area for future extensions of netCDF)
   !
-  !=== gtool5 Υǡ¤ (gtdata) ˴ؤ륨顼
+  !=== gtool5 のデータ構造 (gtdata) に関するエラーコード
   !=== Error codes for data structure of gtool5 (gtdata)
   !
-  ! ʲΥ顼ɤ˴ؤƤ dc_error ⥸塼Ѥ뤳Ȥ
-  ! ѤƤ
+  ! 以下のエラーコードに関しては dc_error モジュールを引用することで
+  ! 利用してください。
   !
-  ! Use following error codes by refering this "dc_error" module. 
+  ! Use following error codes by refering this "dc_error" module.
   !
-  ! <b>. Number</b> :: <b>  [ ˡ˥å. Mnemonic ] 顼å. Error message</b>
+  ! <b>数値. Number</b> :: <b>  [ ニーモニック. Mnemonic ] エラーメッセージ. Error message</b>
   !
   ! -100    :: [ <b>GT_EFAKE           </b> ]
   !            <b></b> :: function not implemented
@@ -304,43 +304,43 @@ module dc_error
   !
   ! -118    :: [ <b>GT_ERANKMISMATCH</b> ]
   !            <b></b> :: rank of data and argument is mismatch (<i>cause_c</i>)
-  ! -119    :: [ <b>GT_ENOTURL     </b> ] 
+  ! -119    :: [ <b>GT_ENOTURL     </b> ]
   !            <b></b> :: URL (<i>cause_c</i>) is not found
   !
-  ! -120    :: [ <b>GT_EBADGT4COMMAGRAPHY     </b> ] 
+  ! -120    :: [ <b>GT_EBADGT4COMMAGRAPHY     </b> ]
   !            <b></b> :: (<i>cause_c</i>) is not gtool4 comma-graphy (ex. "time=100.0,x=10:20,y=^1:^5")
   !
   !
-  ! -299  :: <b>                     </b>
-  !            <b></b> :: ( gtdata ؤγĥΤͽ.
+  ! 〜-299  :: <b>                     </b>
+  !            <b></b> :: (将来の gtdata 層の拡張のための予約.
   !                       Reserved area for future extensions of gtdata layer)
   !
-  !=== GrADS ǡϤ˴ؤ륨顼
+  !=== GrADS データ入出力に関するエラーコード
   !=== Error codes for GrADS data I/O
   !
-  ! ʲΥ顼ɤ˴ؤƤ dc_error ⥸塼Ѥ뤳Ȥ
-  ! ѤƤ
+  ! 以下のエラーコードに関しては dc_error モジュールを引用することで
+  ! 利用してください。
   !
-  ! Use following error codes by refering this "dc_error" module. 
+  ! Use following error codes by refering this "dc_error" module.
   !
-  ! <b>. Number</b> :: <b>  [ ˡ˥å. Mnemonic ] 顼å. Error message</b>
+  ! <b>数値. Number</b> :: <b>  [ ニーモニック. Mnemonic ] エラーメッセージ. Error message</b>
   !
   ! -300    :: [ <b>GR_ENOTGR          </b> ]
   !            <b></b> :: invalid GrADS file
   !
-  ! -399  :: <b>                     </b>
-  !            <b></b> :: ( GrADS data ؤγĥΤͽ.
+  ! 〜-399  :: <b>                     </b>
+  !            <b></b> :: (将来の GrADS data 入出力層の拡張のための予約.
   !                       Reserved area for future extensions of GrADS data I/O layer)
   !
-  !=== DC 桼ƥƥѥ顼
+  !=== DC ユーティリティ用エラーコード
   !=== Error codes for DC utilities
   !
-  ! ʲΥ顼ɤ˴ؤƤ dc_error ⥸塼Ѥ뤳Ȥ
-  ! ѤƤ
+  ! 以下のエラーコードに関しては dc_error モジュールを引用することで
+  ! 利用してください。
   !
-  ! Use following error codes by refering this "dc_error" module. 
+  ! Use following error codes by refering this "dc_error" module.
   !
-  ! <b>. Number</b> :: <b>  [ ˡ˥å. Mnemonic ] 顼å. Error message</b>
+  ! <b>数値. Number</b> :: <b>  [ ニーモニック. Mnemonic ] エラーメッセージ. Error message</b>
   !
   ! -400    :: [ <b>DC_ENOTINIT          </b> ]
   !            <b></b> :: object (<i>cause_c</i>) is not initialized
@@ -403,108 +403,108 @@ module dc_error
   !            <b></b> :: calendar and date are inconsistent
   !
   !
-  ! -420-499  :: <b>                     </b>
-  !                <b></b> :: ( DC 桼ƥƥγĥΤͽ.
+  ! -420〜-499  :: <b>                     </b>
+  !                <b></b> :: (将来の DC ユーティリティの拡張のための予約.
   !                           Reserved area for future extensions of DC utilities)
   !
-  !=== ǡ (gtool_history, gtool_history_nmlinfo, gtool_historyauto) 顼
+  !=== データ入出力層 (gtool_history, gtool_history_nmlinfo, gtool_historyauto) エラーコード
   !=== Error codes for data I/O layer (gtool_history, gtool_history_nmlinfo, gtool_historyauto)
   !
-  ! ʲΥ顼ɤ˴ؤƤ dc_error ⥸塼Ѥ뤳Ȥ
-  ! ѤƤ
+  ! 以下のエラーコードに関しては dc_error モジュールを引用することで
+  ! 利用してください。
   !
-  ! Use following error codes by refering this "dc_error" module. 
+  ! Use following error codes by refering this "dc_error" module.
   !
-  ! <b>. Number</b> :: <b>  [ ˡ˥å. Mnemonic ] 顼å. Error message</b>
+  ! <b>数値. Number</b> :: <b>  [ ニーモニック. Mnemonic ] エラーメッセージ. Error message</b>
   !
-  ! -500    :: [ <b>HST_ENOTINDEFINE</b> ] 
+  ! -500    :: [ <b>HST_ENOTINDEFINE</b> ]
   !            <b></b> :: operation (<i>cause_c</i>) not allowed in data mode
   !
-  ! -501    :: [ <b>HST_EINDEFINE   </b> ] 
+  ! -501    :: [ <b>HST_EINDEFINE   </b> ]
   !            <b></b> :: operation (<i>cause_c</i>) not allowed in define mode
   !
-  ! -502    :: [ <b>HST_EINTFILE   </b> ] 
-  !            <b></b> :: different intervals are applied to a file (<i>cause_c</i>) 
-  ! -503    :: [ <b>HST_EBADNAME   </b> ] 
+  ! -502    :: [ <b>HST_EINTFILE   </b> ]
+  !            <b></b> :: different intervals are applied to a file (<i>cause_c</i>)
+  ! -503    :: [ <b>HST_EBADNAME   </b> ]
   !            <b></b> :: name (<i>cause_c</i>) is invalid
   !
-  ! -504    :: [ <b>HST_ENOTTERMGTHIST   </b> ] 
+  ! -504    :: [ <b>HST_ENOTTERMGTHIST   </b> ]
   !            <b></b> :: GT_HISTORY correspond to (<i>cause_c</i>) is not terminated
   !
-  ! -505    :: [ <b>HST_ENODEPENDTIME   </b> ] 
+  ! -505    :: [ <b>HST_ENODEPENDTIME   </b> ]
   !            <b></b> :: (<i>cause_c</i>) does not depend on time
   !
-  ! -506    :: [ <b>HST_EBADVARNAME   </b> ] 
+  ! -506    :: [ <b>HST_EBADVARNAME   </b> ]
   !            <b></b> :: variable name (<i>cause_c</i>) is invalid
   !
-  ! -507    :: [ <b>HST_ENOTIMEDIM   </b> ] 
+  ! -507    :: [ <b>HST_ENOTIMEDIM   </b> ]
   !            <b></b> :: time dimension is not found
   !
-  ! -508    :: [ <b>HST_ENOAXISNAME   </b> ] 
+  ! -508    :: [ <b>HST_ENOAXISNAME   </b> ]
   !            <b></b> :: axis or weight (<i>cause_c</i>) is not found
   !
-  ! -509    :: [ <b>HST_EVARINUSE   </b> ] 
-  !            <b></b> :: variable name (<i>cause_c</i>) is already used 
+  ! -509    :: [ <b>HST_EVARINUSE   </b> ]
+  !            <b></b> :: variable name (<i>cause_c</i>) is already used
   !
-  ! -510    :: [ <b>HST_EALREADYREGVARFIX   </b> ] 
+  ! -510    :: [ <b>HST_EALREADYREGVARFIX   </b> ]
   !            <b></b> :: already register of variables is fixed by (<i>cause_c</i>)
   !
-  ! -511    :: [ <b>HST_EBADSLICE   </b> ] 
+  ! -511    :: [ <b>HST_EBADSLICE   </b> ]
   !            <b></b> :: slice options are invalid (<i>cause_c</i>)
   !
-  ! -512    :: [ <b>HST_EBADNEWFILEINT   </b> ] 
+  ! -512    :: [ <b>HST_EBADNEWFILEINT   </b> ]
   !            <b></b> :: invalid newfile interval (<i>cause_c</i>)
   !
-  ! -513    :: [ <b>HST_EMAXDIMSDEPENDED   </b> ] 
+  ! -513    :: [ <b>HST_EMAXDIMSDEPENDED   </b> ]
   !            <b></b> :: variable (<i>cause_c</i>) depends on (<i>cause_i</i>) dimensions
   !
-  ! -514    :: [ <b>HST_EINDIVISIBLE   </b> ] 
+  ! -514    :: [ <b>HST_EINDIVISIBLE   </b> ]
   !            <b></b> :: (<i>cause_c</i>) can not be divided
   !
-  ! -515    :: [ <b>HST_EBADTERMINUS   </b> ] 
+  ! -515    :: [ <b>HST_EBADTERMINUS   </b> ]
   !            <b></b> :: terminus options are invalid (<i>cause_c</i>)
 
-  ! -516    :: [ <b>HST_EBADORIGIN   </b> ] 
+  ! -516    :: [ <b>HST_EBADORIGIN   </b> ]
   !            <b></b> :: origin options are invalid (<i>cause_c</i>)
   !
-  ! -517    :: [ <b>HST_EMPINOAXISDATA   </b> ] 
+  ! -517    :: [ <b>HST_EMPINOAXISDATA   </b> ]
   !            <b></b> :: data of axis (<i>cause_c</i>) for MPI is lack
   !
-  !=== gtool5 ξγĥΤͽ󤷤Ƥ륨顼
+  !=== gtool5 の将来の拡張のために予約してあるエラーコード
   !=== Reserved error codes for future extensions of gtool5
   !
-  ! ʲΥ顼ɤϺγĥͤͽ󤷤ƤʬǤ
+  ! 以下のエラーコードは今後の拡張も考えて予約してある部分です。
   !
   ! Following error codes are reserved for future extensions.
   !
-  ! <b>. Number</b> :: <b>  [ ˡ˥å. Mnemonic ] 顼å. Error message</b>
+  ! <b>数値. Number</b> :: <b>  [ ニーモニック. Mnemonic ] エラーメッセージ. Error message</b>
   !
-  ! -600-999  :: <b>                     </b>
-  !                <b></b> :: ( gtool5 γĥΤͽ.
+  ! -600〜-999  :: <b>                     </b>
+  !                <b></b> :: (将来の gtool5 の拡張のための予約.
   !                           Reserved area for future extensions of gtool5)
   !
-  !=== 桼ѥ顼
+  !=== ユーザ定義用エラーコード
   !=== User-defined error codes
   !
-  ! -1000 ⾮顼ɤϡ
-  ! gtool5 ξ̤ΥץबѤ륨顼ɤȤƶƤޤ
+  ! -1000 よりも小さいエラーコードは、
+  ! gtool5 の上位のプログラムが利用するエラーコードとして空けてあります。
   !
-  ! Error codes smaller than -1000 are saved for as user-defined error codes 
+  ! Error codes smaller than -1000 are saved for as user-defined error codes
   ! used by upper programs.
   !
-  ! <b>. Number</b> :: <b>  [ ˡ˥å. Mnemonic ] 顼å. Error message</b>
+  ! <b>数値. Number</b> :: <b>  [ ニーモニック. Mnemonic ] エラーメッセージ. Error message</b>
   !
-  ! -1000 :: [ <b>USR_ERRNO           </b> ]
+  ! -1000〜 :: [ <b>USR_ERRNO           </b> ]
   !            <b></b> :: <i>cause_c</i> (<i>cause_i</i>)
   !
 
-  use netcdf_f77, only: NF_ENOTVAR, NF_EINVAL
+  use netcdf, only: NF90_ENOTVAR, NF90_EINVAL
   use dc_types, only: STRING
   implicit none
   private
-  public :: NF_ENOTVAR, NF_EINVAL
+  public :: NF90_ENOTVAR, NF90_EINVAL
 
-  ! 顼ݻ
+  ! エラー等を保持
 
   integer, public, parameter   :: DC_NOERR  = 0
   integer, private, save       :: errno     = DC_NOERR
@@ -513,17 +513,17 @@ module dc_error
   character(STRING), private, save :: cause_string = ""
   character(STRING), private, save :: cause_location = ""
 
-  ! Υ顼ֹ libc ƥ२顼åΤ
-  ! Ƥ롣ƥ¸礭礭ʿͤ
-  ! ѤΤǶΰݤΤϺǤ롣
+  ! 正のエラー番号は libc システムエラーメッセージのために
+  ! あけてある。システム依存性が大きく、非常に大きな数値も
+  ! 用いられるので空き領域を確保するのは困難である。
   !
-  ! Υ顼ֹ netCDF ȤäƤ롣γĥ⸫ǡ
-  ! -99 ޤǤϻȤʤ֤
+  ! 負のエラー番号は netCDF が使っている。少々の拡張も見込んで、
+  ! -99 までは使わないで置く。
 
   integer, parameter, public:: GT_EFAKE = -100
 
   !
-  ! -101 ʲ: ǡ¤Υ顼
+  ! -101 以下: データ構造のエラー
   !
   integer, parameter, public:: GT_ENOMOREDIMS        = -101
   integer, parameter, public:: GT_EDIMNODIM          = -102
@@ -547,12 +547,12 @@ module dc_error
   integer, parameter, public:: GT_EBADGT4COMMAGRAPHY = -120
 
   !
-  ! -300 ʲ: GrADS ϤΥ顼
+  ! -300 以下: GrADS 入出力のエラー
   !
   integer, parameter, public:: GR_ENOTGR = -300
 
   !
-  ! -400 ʲ: dc 桼ƥƥΥ顼
+  ! -400 以下: dc ユーティリティのエラー
   !
   integer, parameter, public:: DC_ENOTINIT       = -400
   integer, parameter, public:: DC_EALREADYINIT   = -401
@@ -576,7 +576,7 @@ module dc_error
   integer, parameter, public:: DC_EINCONSISTCALDATE = -419
 
   !
-  ! -500 ʲ: ǡؤΥ顼
+  ! -500 以下: データ入出力層のエラー
   !
   integer, parameter, public:: HST_ENOTINDEFINE      = -500
   integer, parameter, public:: HST_EINDEFINE         = -501
@@ -599,15 +599,15 @@ module dc_error
 
 
   !
-  ! -1000 ʲ: 桼
+  ! -1000 以下: ユーザー定義
   !
   integer, parameter, public:: USR_ERRNO = -1000
 
   public:: StoreError, DumpError, GetErrorMessage, ErrorCode
   !
-  ! === ³ѻ ===
+  ! === 手続引用仕様 ===
   !
-  ! 캹ؤ褦˳ؿˤƤ
+  ! いずれ差し替えられるように外部関数にしておく。
 
   interface
     subroutine DumpError()
@@ -618,7 +618,7 @@ contains
 
   integer function ErrorCode() result(result)
     !
-    ! ꤵƤ륨顼ɤ֤ޤ
+    ! 現在設定されているエラーコードを返します。
     !
     ! Return an error code specified currently.
     !
@@ -627,11 +627,11 @@ contains
 
   subroutine GetErrorMessage(msg)
     !
-    ! ꤵƤ륨顼ɤбå֤ޤ
+    ! 現在設定されているエラーコードから対応するメッセージを返します。
     !
     ! Return messages corresponding to an error code specified currently.
     !
-    use netcdf_f77, only: nf_strerror
+    use netcdf, only: nf90_strerror
     character(len = *), intent(out):: msg
     character(len = STRING):: message
     character(len = 20):: errno_c
@@ -641,7 +641,7 @@ contains
     case(GT_EFAKE)
       msg = ' function not implemented'
       !
-      ! -101 ʲ: ǡ¤Υ顼
+      ! -101 以下: データ構造のエラー
       ! -101 or less: Error of data structure
       !
     case(GT_ENOMOREDIMS)
@@ -684,13 +684,13 @@ contains
     case(GT_EBADGT4COMMAGRAPHY)
       msg = ' (' // trim(cause_string) // ') is not gtool4 comma-graphy (ex. "time=100.0,x=10:20,y=^1:^5")'
       !
-      ! -300 ʲ: GrADS ϤΥ顼
+      ! -300 以下: GrADS 入出力のエラー
       ! -300 or less: Error of GrADS I/O
       !
     case(GR_ENOTGR)
       msg = ' invalid GrADS file'
       !
-      ! -400 ʲ: DC 桼ƥƥΥ顼
+      ! -400 以下: DC ユーティリティのエラー
       ! -400 or less: Error of DC utilities
       !
     case(DC_ENOTINIT)
@@ -735,7 +735,7 @@ contains
     case(DC_EINCONSISTCALDATE)
       msg = ' calendar and date are inconsistent'
       !
-      ! -500 ʲ: ǡؤΥ顼
+      ! -500 以下: データ入出力層のエラー
       ! -500 or less: Error of data I/O layer
       !
     case(HST_ENOTINDEFINE)
@@ -779,7 +779,7 @@ contains
 
       !
       !
-      ! -1000 ʲ: 桼
+      ! -1000 以下: ユーザー定義
       ! -1000 or less: User-defined error
       !
     case(:USR_ERRNO)
@@ -803,14 +803,14 @@ contains
 
 999 continue
     if (len(cause_string) > 0) then
-      message = nf_strerror(errno)
+      message = nf90_strerror(errno)
       write(errno_c, "(i8)") errno
       msg =  '*** ERROR (Code ' // trim(adjustl(errno_c)) // &
         & ') [' // trim(cause_location)             // &
         & '('   // trim(cause_string) // ')] ***  ' // &
         & trim(message)
     else if (cause_int_valid) then
-      message = nf_strerror(errno)
+      message = nf90_strerror(errno)
       write(errno_c, "(i8)") errno
       write(cause_int_c, "(i8)") cause_int
       msg =  '*** ERROR (Code ' // trim(adjustl(errno_c)) // &
@@ -818,7 +818,7 @@ contains
         & '('   // trim(adjustl(cause_int_c)) // ')] ***  ' // &
         & trim(message)
     else
-      message = nf_strerror(errno)
+      message = nf90_strerror(errno)
       write(errno_c, "(i8)") errno
       msg =  '*** ERROR (Code ' // trim(adjustl(errno_c))  // &
         & ') [' // trim(cause_location) // '] ***  ' // &
@@ -828,91 +828,91 @@ contains
 
   subroutine StoreError(number, where, err, cause_c, cause_i)
     !
-    !== ŵŪ饤֥³Τ˺줿顼֥롼
+    !== 典型的ライブラリ手続のために作られたエラー処理サブルーチン
     !== Error handling subroutine for typical procedures of library
     !
-    ! ɬפʰ2ĤǤꡢ1 *number* ˤΥ顼ɡ
-    ! 2 *where* ˤʸǥ顼ȯ³̾Ϳޤ
-    ! ǥեȤǤϰʲηʸɸϤɽƥץ
-    ! Ͻλޤ 顼å error_message
-    ! ϥ顼ɤ鼫ưŪ˷ޤޤ
-    ! бɽ顼ɰˤΤǻȤƤ
+    ! 必要な引数は2つであり、第1引数 *number* には整数型のエラーコード、
+    ! 第2引数 *where* には文字型でエラーの発生した手続名を与えます。
+    ! デフォルトでは以下の形式の文字列が標準出力に表示されてプログラム
+    ! は終了します。 エラーメッセージ error_message
+    ! はエラーコードから自動的に決まります。
+    ! 対応表がエラーコード一覧にあるので参照してください。
     !
-    ! Number of necessary arguments is two. Give integer error code 
+    ! Number of necessary arguments is two. Give integer error code
     ! to first argument *number*, and procedure name where the error
-    ! occurs to second argument *where*. By default, like a following 
+    ! occurs to second argument *where*. By default, like a following
     ! string is displayed to standard output, and the program aborts
     ! Error message <error_message> is determined by error code automatically.
     ! See error code list.
     !
-    !     
+    !
     !     *** ERROR (Code number) [where] ***  error_message
-    !     
+    !
     !     *** ERROR (Code number) [where(cause_c)] ***  error_message
     !
-    ! ʤgtool5 Υ饤֥곰桼顼ѥġ
-    ! Ȥ StoreError Ѥ뤳Ȥꤷ<b><tt>USR_ERRNO</tt></b> 
-    ! ֤꾮
-    ! 顼ɤ϶Ƥޤ<b><tt>USR_ERRNO</tt></b>
-    ! 꾮ͤ򥨥顼ɤͿ,
-    ! StoreError ϰʲηʸɸϤ˽Ϥƥץ
-    ! λޤ°פ˻ȤåϤӥ顼ȯ
-    ! Υ⥸塼Ȥ *dc_message* ѰդƤΤ
-    ! ⻲ȤƤ
+    ! なお、gtool5 のライブラリ外からユーザがエラー処理用ツール
+    ! として StoreError を用いることを想定し、<b><tt>USR_ERRNO</tt></b>
+    ! 番より小さい
+    ! エラーコードは空けてあります。<b><tt>USR_ERRNO</tt></b>
+    ! より小さい値をエラーコードに与えると,
+    ! StoreError は以下の形式の文字列を標準出力に出力してプログラムを
+    ! 終了させます。より安易に使えるメッセージ出力およびエラー発生の
+    ! ためのモジュールとして *dc_message* も用意してあるので
+    ! そちらも参照してください。
     !
-    ! In addition, for usage that users call StoreError as an error 
-    ! handling tool from the outside of gtool5 library, 
+    ! In addition, for usage that users call StoreError as an error
+    ! handling tool from the outside of gtool5 library,
     ! error codes smaller than <b><tt>USR_ERRNO</tt></b> is saved.
     ! When error codes smaller than <b><tt>USR_ERRNO</tt></b> is given,
-    ! StoreError displays like a following string to standard output, 
+    ! StoreError displays like a following string to standard output,
     ! and stops the program.
-    ! *dc_message* module is prepared too. This module can be used 
+    ! *dc_message* module is prepared too. This module can be used
     ! more easily for message output and rise of error.
     !
-    !     
+    !
     !     *** ERROR (Code number) [where] ***  cause_c
-    !     
+    !
     !     *** ERROR (Code number) [where] ***  cause_c (cause_i)
     !
     !--
-    !== ȯԸ
+    !== 開発者向け解説
     !
-    ! 顼ֹ number  errno ˳Ǽ롣ƱտŪ
-    ! where, cause_i  cause_location, cause_string,
-    ! cause_int ˳Ǽ롣 
-    ! err ͿƤ硢err  number  DC_NOERR ξˤʤ롣
-    ! number  DC_NOERR ʤ¨롣
-    ! err ͿƤʤХ顼å * ˽Ϥ
-    ! ץλ롣
+    ! エラー番号 number を errno に格納する。同時に付随的情報
+    ! where, cause_i を cause_location, cause_string,
+    ! cause_int に格納する。
+    ! err が与えられている場合、err は number が DC_NOERR の場合だけ偽になる。
+    ! number が DC_NOERR ならば即復帰する。
+    ! err が与えられていなければエラーメッセージを装置 * に出力して
+    ! プログラムを終了する。
     !++
 
     integer,            intent(in)            :: number
-                              ! 顼ɡ 
+                              ! エラーコード。
                               ! Error code
     character(len = *), intent(in)            :: where
-                              ! 顼ȯĽꡣ 
+                              ! エラー発生個所。
                               ! Place where error occurs
     logical,            intent(out), optional :: err
-                              ! 㳰ѥե饰
-                              ! ǥեȤǤϡ*number* 󥨥顼
-                              ! ʳͤͿ줿硢顼å
-                              ! ɽƥץ϶λޤ
-                              !  *err* Ϳ硢
-                              ! ץ϶λ
-                              ! *err*  .true. ޤ
+                              ! 例外処理用フラグ。
+                              ! デフォルトでは、*number* に非エラーコード
+                              ! 以外の値が与えられた場合、エラーメッセージを
+                              ! 表示してプログラムは強制終了します。
+                              ! 引数 *err* が与えられる場合、
+                              ! プログラムは強制終了せず、代わりに
+                              ! *err* に .true. が代入されます。
                               !
-                              ! Exception handling flag. 
-                              ! By default, when error code (excluding 
-                              ! non error code) is given to *number*, 
-                              ! the program display error message and aborts. 
-                              ! If this *err* argument is given, 
-                              ! .true. is substituted to *err* and 
-                              ! the program does not abort. 
+                              ! Exception handling flag.
+                              ! By default, when error code (excluding
+                              ! non error code) is given to *number*,
+                              ! the program display error message and aborts.
+                              ! If this *err* argument is given,
+                              ! .true. is substituted to *err* and
+                              ! the program does not abort.
     character(len = *), intent(in),  optional :: cause_c
-                              ! ʸå 
+                              ! 文字型メッセージ。
                               ! Character message
     integer,            intent(in),  optional :: cause_i
-                              ! å 
+                              ! 整数型メッセージ。
                               ! Integer message
   continue
     if (present(err)) then
@@ -940,10 +940,10 @@ end module dc_error
 
 subroutine DumpError()
   !
-  ! GetErrorMessage 饨顼å塢
-  !  sysdep#AbortProgram Ϥƥץλޤ
+  ! GetErrorMessage からエラーメッセージを取得後、
+  ! それを sysdep#AbortProgram に渡してプログラムを終了させます。
   !
-  ! Get error messages from "GetErrorMessage", and put the messages 
+  ! Get error messages from "GetErrorMessage", and put the messages
   ! to sysdep#AbortProgram, and stop the program.
   !
   use dc_types, only: STRING
