@@ -1,20 +1,20 @@
-!== dc_date_types#DC_DATETIME, dc_date_types#DC_DIFFTIME ѿäؤѴ
+!== dc_date_types#DC_DATETIME, dc_date_types#DC_DIFFTIME 型変数から月日秒への変換
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
 ! Version::   $Id: dcdatetimeeval.f90,v 1.2 2009-05-25 10:01:34 morikawa Exp $
-! Tag Name::  $Name: gtool5-20101228-1 $
+! Tag Name::  $Name:  $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2006. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
-! Υե󶡤³ dc_date ⥸塼ˤ󶡤ޤ
+! このファイルで提供される手続き群は dc_date モジュールにて提供されます。
 !
 
 subroutine DCDateTimeEval1(time, year, mon, day, hour, min, &
   & sec, caltype, zone, sclyear, sclmon, sclday, sclsec)
   !
-  ! dc_date_types#DC_DATETIME ѿ *time* 
-  ! ǯ *year*,  *mon*,  *day*,  *hour*, ʬ *min*,  *sec*,
-  ! ˡ *caltype*, ॾ *zone* Ѵ֤ޤ.
+  ! dc_date_types#DC_DATETIME 型変数 *time* を
+  ! 年 *year*, 月 *mon*, 日 *day*, 時間 *hour*, 分 *min*, 秒 *sec*,
+  ! 暦法 *caltype*, タイムゾーン *zone* に変換して返します.
   !
   use dc_types, only: DP
   use dc_date_types, only: DC_DATETIME, &
@@ -29,18 +29,18 @@ subroutine DCDateTimeEval1(time, year, mon, day, hour, min, &
   use dc_trace, only: BeginSub, EndSub
   implicit none
   type(DC_DATETIME), intent(in):: time
-  integer, intent(out), optional:: year ! ǯ
-  integer, intent(out), optional:: mon  ! 
-  integer, intent(out), optional:: day  ! 
-  integer, intent(out), optional:: hour ! 
-  integer, intent(out), optional:: min  ! ʬ
-  real(DP),intent(out), optional:: sec  ! 
-  integer, intent(out), optional:: caltype ! ˡ
-  character(*), intent(out), optional:: zone ! ॾ (UTC λ)
-  type(DC_SCALED_SEC), intent(out), optional:: sclyear ! ǯ (DC_SCALED_SEC )
-  type(DC_SCALED_SEC), intent(out), optional:: sclmon  !  (DC_SCALED_SEC )
-  type(DC_SCALED_SEC), intent(out), optional:: sclday  !  (DC_SCALED_SEC )
-  type(DC_SCALED_SEC), intent(out), optional:: sclsec  !  (DC_SCALED_SEC )
+  integer, intent(out), optional:: year ! 年
+  integer, intent(out), optional:: mon  ! 月
+  integer, intent(out), optional:: day  ! 日
+  integer, intent(out), optional:: hour ! 時
+  integer, intent(out), optional:: min  ! 分
+  real(DP),intent(out), optional:: sec  ! 秒
+  integer, intent(out), optional:: caltype ! 暦法
+  character(*), intent(out), optional:: zone ! タイムゾーン (UTC からの時差)
+  type(DC_SCALED_SEC), intent(out), optional:: sclyear ! 年 (DC_SCALED_SEC 型)
+  type(DC_SCALED_SEC), intent(out), optional:: sclmon  ! 月 (DC_SCALED_SEC 型)
+  type(DC_SCALED_SEC), intent(out), optional:: sclday  ! 日 (DC_SCALED_SEC 型)
+  type(DC_SCALED_SEC), intent(out), optional:: sclsec  ! 秒 (DC_SCALED_SEC 型)
 
   type(DC_SCALED_SEC):: iyear, month, iday, imon, isec
   !character(*), parameter :: subname = 'DCDateTimeEval1'
@@ -146,9 +146,9 @@ subroutine DCDiffTimeEval1(diff, &
   & year, mon, day, hour, min, sec, nondim, &
   & sclyear, sclmon, sclday, sclsec, sclnondim, err)
   !
-  ! dc_date_types#DC_DIFFTIME ѿ *diff* 
-  ! ǯ *year*,  *mon*,  *day*,  *hour*, ʬ *min*,  *sec*,
-  ! ̵ *nondim* Ѵ֤ޤ.
+  ! dc_date_types#DC_DIFFTIME 型変数 *diff* を
+  ! 年 *year*, 月 *mon*, 日 *day*, 時間 *hour*, 分 *min*, 秒 *sec*,
+  ! 無次元時間 *nondim* に変換して返します.
   !
   use dc_types, only: DP
   use dc_trace, only: BeginSub, EndSub
@@ -162,18 +162,18 @@ subroutine DCDiffTimeEval1(diff, &
     & abs, int, floor, ceiling
   implicit none
   type(DC_DIFFTIME), intent(in):: diff
-  integer, intent(out), optional:: year ! ǯ
-  integer, intent(out), optional:: mon  ! 
-  integer, intent(out), optional:: day  ! 
-  integer, intent(out), optional:: hour ! 
-  integer, intent(out), optional:: min  ! ʬ
-  real(DP),intent(out), optional:: sec  ! 
-  real(DP),intent(out), optional:: nondim  ! ̵. Nondimensional time
-  type(DC_SCALED_SEC), intent(out), optional:: sclyear ! ǯ (DC_SCALED_SEC )
-  type(DC_SCALED_SEC), intent(out), optional:: sclmon  !  (DC_SCALED_SEC )
-  type(DC_SCALED_SEC), intent(out), optional:: sclday  !  (DC_SCALED_SEC )
-  type(DC_SCALED_SEC), intent(out), optional:: sclsec  !  (DC_SCALED_SEC )
-  type(DC_SCALED_SEC), intent(out), optional:: sclnondim  ! ̵ (DC_SCALED_SEC )
+  integer, intent(out), optional:: year ! 年
+  integer, intent(out), optional:: mon  ! 月
+  integer, intent(out), optional:: day  ! 日
+  integer, intent(out), optional:: hour ! 時
+  integer, intent(out), optional:: min  ! 分
+  real(DP),intent(out), optional:: sec  ! 秒
+  real(DP),intent(out), optional:: nondim  ! 無次元時間. Nondimensional time
+  type(DC_SCALED_SEC), intent(out), optional:: sclyear ! 年 (DC_SCALED_SEC 型)
+  type(DC_SCALED_SEC), intent(out), optional:: sclmon  ! 月 (DC_SCALED_SEC 型)
+  type(DC_SCALED_SEC), intent(out), optional:: sclday  ! 日 (DC_SCALED_SEC 型)
+  type(DC_SCALED_SEC), intent(out), optional:: sclsec  ! 秒 (DC_SCALED_SEC 型)
+  type(DC_SCALED_SEC), intent(out), optional:: sclnondim  ! 無次元時間 (DC_SCALED_SEC 型)
   logical, intent(out), optional :: err
   type(DC_SCALED_SEC):: imon, isec
   integer:: stat
@@ -247,8 +247,8 @@ end subroutine DCDiffTimeEval1
 
 function DCDateTimeEvalDay(time) result(result)
   !
-  ! dc_date_types#DC_DATETIME ѿ˴
-  ! ټ¿ѿ֤ޤ. (㤨 12 ֤ 0.5 ȴޤ).
+  ! dc_date_types#DC_DATETIME 型変数の日時を日数に換算して
+  ! 倍精度実数型変数で返します. (例えば 12 時間は 0.5 日と換算されます).
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -265,10 +265,10 @@ end function DCDateTimeEvalDay
 
 function DCDiffTimeEvalDay(diff) result(result)
   !
-  ! dc_date_types#DC_DIFFTIME ѿ˴
-  ! ټ¿ѿ֤ޤ. (㤨 12 ֤ 0.5 ȴޤ).
+  ! dc_date_types#DC_DIFFTIME 型変数の日時を日数に換算して
+  ! 倍精度実数型変数で返します. (例えば 12 時間は 0.5 日と換算されます).
   !
-  ! 1  dc_date_types#CYCLIC_MDAYS ȴޤ.
+  ! 1 ヶ月は dc_date_types#CYCLIC_MDAYS と換算します.
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -287,9 +287,9 @@ end function DCDiffTimeEvalDay
 
 function DCDateTimeEvalHour(time) result(result)
   !
-  ! dc_date_types#DC_DATETIME ѿ֤˴
-  ! ټ¿ѿ֤ޤ.
-  ! (㤨 2  48 ֤, 30 ʬ  0.5 ֤ȴޤ).
+  ! dc_date_types#DC_DATETIME 型変数の日時を時間に換算して
+  ! 倍精度実数型変数で返します.
+  ! (例えば 2 日は 48 時間に, 30 分 は 0.5 時間と換算されます).
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -307,11 +307,11 @@ end function DCDateTimeEvalHour
 
 function DCDiffTimeEvalHour(diff) result(result)
   !
-  ! dc_date_types#DC_DIFFTIME ѿ֤˴
-  ! ټ¿ѿ֤ޤ. 
-  ! (㤨 2  48 ֤, 30 ʬ  0.5 ֤ȴޤ).
+  ! dc_date_types#DC_DIFFTIME 型変数の日時を時間に換算して
+  ! 倍精度実数型変数で返します. 
+  ! (例えば 2 日は 48 時間に, 30 分 は 0.5 時間と換算されます).
   !
-  ! 1  dc_date_types#CYCLIC_MDAYS ȴޤ.
+  ! 1 ヶ月は dc_date_types#CYCLIC_MDAYS と換算します.
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -331,9 +331,9 @@ end function DCDiffTimeEvalHour
 
 function DCDateTimeEvalMin(time) result(result)
   !
-  ! dc_date_types#DC_DATETIME ѿʬ˴
-  ! ټ¿ѿ֤ޤ.
-  ! (㤨 1  3600 ʬ, 30   0.5 ʬȴޤ).
+  ! dc_date_types#DC_DATETIME 型変数の日時を分に換算して
+  ! 倍精度実数型変数で返します.
+  ! (例えば 1 日は 3600 分に, 30 秒 は 0.5 分と換算されます).
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -351,11 +351,11 @@ end function DCDateTimeEvalMin
 
 function DCDiffTimeEvalMin(diff) result(result)
   !
-  ! dc_date_types#DC_DIFFTIME ѿʬ˴
-  ! ټ¿ѿ֤ޤ. 
-  ! (㤨 1  3600 ʬ, 30   0.5 ʬȴޤ).
+  ! dc_date_types#DC_DIFFTIME 型変数の日時を分に換算して
+  ! 倍精度実数型変数で返します. 
+  ! (例えば 1 日は 3600 分に, 30 秒 は 0.5 分と換算されます).
   !
-  ! 1  dc_date_types#CYCLIC_MDAYS ȴޤ.
+  ! 1 ヶ月は dc_date_types#CYCLIC_MDAYS と換算します.
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -375,12 +375,12 @@ end function DCDiffTimeEvalMin
 
 function DCDateTimeEvalSec(time) result(result)
   !
-  ! dc_date_types#DC_DATETIME ѿä˴
-  ! ټ¿ѿ֤ޤ.
+  ! dc_date_types#DC_DATETIME 型変数の日時を秒に換算して
+  ! 倍精度実数型変数で返します.
   !
-  ! ǯǤ̵뤵ޤ. ʤ, 1999-01-01 Ǽ줿 time 
-  ! 2007-01-01 Ǽ줿 time Ʊ֤ͤޤ.
-  ! (Ϥ⤷˾ޤ̵ư⤷ޤ).
+  ! 年の要素は無視されます. すなわち, 1999-01-01 が格納された time と
+  ! 2007-01-01 が格納された time からは同じ値が返ります.
+  ! (これはもしかすると望ましく無い動作かもしれません).
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -399,10 +399,10 @@ end function DCDateTimeEvalSec
 
 function DCDiffTimeEvalSec(diff) result(result)
   !
-  ! dc_date_types#DC_DIFFTIME ѿä˴
-  ! ټ¿ѿ֤ޤ.
+  ! dc_date_types#DC_DIFFTIME 型変数の日時を秒に換算して
+  ! 倍精度実数型変数で返します.
   !
-  ! 1  dc_date_types#CYCLIC_MDAYS ȴޤ.
+  ! 1 ヶ月は dc_date_types#CYCLIC_MDAYS と換算します.
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -425,10 +425,10 @@ end function DCDiffTimeEvalSec
 
 function DCDiffTimeEvalNondim(diff) result(result)
   !
-  ! dc_date_types#DC_DIFFTIME ѿ̵»֤˴
-  ! ټ¿ѿ֤ޤ.
+  ! dc_date_types#DC_DIFFTIME 型変数の日時を無時限時間に換算して
+  ! 倍精度実数型変数で返します.
   !
-  ! 1  dc_date_types#CYCLIC_MDAYS ȴޤ.
+  ! 1 ヶ月は dc_date_types#CYCLIC_MDAYS と換算します.
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -444,12 +444,12 @@ end function DCDiffTimeEvalNondim
 
 function DCDateTimeEvalSclSec(time) result(result)
   !
-  ! dc_date_types#DC_DATETIME ѿä˴
-  ! DC_SCALED_SEC ֤ޤ.
+  ! dc_date_types#DC_DATETIME 型変数の日時を秒に換算して
+  ! DC_SCALED_SEC 型で返します.
   !
-  ! ǯǤ̵뤵ޤ. ʤ, 1999-01-01 Ǽ줿 time 
-  ! 2007-01-01 Ǽ줿 time Ʊ֤ͤޤ.
-  ! (Ϥ⤷˾ޤ̵ư⤷ޤ).
+  ! 年の要素は無視されます. すなわち, 1999-01-01 が格納された time と
+  ! 2007-01-01 が格納された time からは同じ値が返ります.
+  ! (これはもしかすると望ましく無い動作かもしれません).
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -467,10 +467,10 @@ end function DCDateTimeEvalSclSec
 
 function DCDiffTimeEvalSclSec(diff) result(result)
   !
-  ! dc_date_types#DC_DIFFTIME ѿä˴
-  ! DC_SCALED_SEC ֤ޤ.
+  ! dc_date_types#DC_DIFFTIME 型変数の日時を秒に換算して
+  ! DC_SCALED_SEC 型で返します.
   !
-  ! 1  dc_date_types#CYCLIC_MDAYS ȴޤ.
+  ! 1 ヶ月は dc_date_types#CYCLIC_MDAYS と換算します.
   !
   use dc_types, only: DP
   use dc_date_generic, only: Eval
@@ -498,22 +498,22 @@ end function DCDiffTimeEvalSclSec
 
 function DCDateTimeEvalByUnit(time, unit, unit_symbol) result(result)
   !
-  ! dc_date_types#DC_DATETIME ѿ *unit* ޤ
-  ! *unit_symbol* ñ
-  ! ˴ټ¿ѿ֤ޤ. 
+  ! dc_date_types#DC_DATETIME 型変数の日時を *unit* または
+  ! *unit_symbol* の単位
+  ! に換算して倍精度実数型変数で返します. 
   ! 
-  ! *unit* ˤ
-  !  dc_date_types#UNIT_DAY,  dc_date_types#UNIT_HOUR,
-  ! ʬ dc_date_types#UNIT_MIN,  dc_date_types#UNIT_SEC 
-  ! Ϳ뤳ȤǽǤ. 
+  ! *unit* には
+  ! 日 dc_date_types#UNIT_DAY, 時 dc_date_types#UNIT_HOUR,
+  ! 分 dc_date_types#UNIT_MIN, 秒 dc_date_types#UNIT_SEC 
+  ! を与えることが可能です. 
   !
-  ! *unit_symbol* ˤ
-  !  dc_date_types#UNIT_SYMBOL_DAY,  dc_date_types#UNIT_SYMBOL_HOUR,
-  ! ʬ dc_date_types#UNIT_SYMBOL_MIN,  dc_date_types#UNIT_SYMBOL_SEC 
-  ! Ϳ뤳ȤǽǤ. 
+  ! *unit_symbol* には
+  ! 日 dc_date_types#UNIT_SYMBOL_DAY, 時 dc_date_types#UNIT_SYMBOL_HOUR,
+  ! 分 dc_date_types#UNIT_SYMBOL_MIN, 秒 dc_date_types#UNIT_SYMBOL_SEC 
+  ! を与えることが可能です. 
   !
-  ! ˳ʤΤ *unit* ޤ *unit_symbol* 
-  ! Ϳ, ⤷ϰξȤͿʤ, 0.0 ֤ޤ.
+  ! これらに該当しないものを *unit* または *unit_symbol* 
+  ! に与えた場合, もしくは引数を両方とも与えない場合, 0.0 が返ります.
   !
   use dc_types, only: DP, TOKEN
   use dc_date_generic, only: EvalSec, EvalMin, EvalHour, EvalDay, ParseTimeUnits
@@ -550,23 +550,23 @@ end function DCDateTimeEvalByUnit
 
 function DCDiffTimeEvalByUnit(diff, unit, unit_symbol) result(result)
   !
-  ! dc_date_types#DC_DIFFTIME ѿ *unit* ñ
-  ! ˴ټ¿ѿ֤ޤ. 
+  ! dc_date_types#DC_DIFFTIME 型変数の日時を *unit* の単位
+  ! に換算して倍精度実数型変数で返します. 
   ! 
-  ! *unit* ˤ
-  !  dc_date_types#UNIT_DAY,  dc_date_types#UNIT_HOUR,
-  ! ʬ dc_date_types#UNIT_MIN,  dc_date_types#UNIT_SEC, 
-  ! ̵ dc_date_types#UNIT_NONDIM
-  ! Ϳ뤳ȤǽǤ. 
+  ! *unit* には
+  ! 日 dc_date_types#UNIT_DAY, 時 dc_date_types#UNIT_HOUR,
+  ! 分 dc_date_types#UNIT_MIN, 秒 dc_date_types#UNIT_SEC, 
+  ! 無次元時間 dc_date_types#UNIT_NONDIM
+  ! を与えることが可能です. 
   ! 
-  ! *unit_symbol* ˤ
-  !  dc_date_types#UNIT_SYMBOL_DAY,  dc_date_types#UNIT_SYMBOL_HOUR,
-  ! ʬ dc_date_types#UNIT_SYMBOL_MIN,  dc_date_types#UNIT_SYMBOL_SEC 
-  ! ̵ dc_date_types#UNIT_SYMBOL_NONDIM
-  ! Ϳ뤳ȤǽǤ. 
+  ! *unit_symbol* には
+  ! 日 dc_date_types#UNIT_SYMBOL_DAY, 時 dc_date_types#UNIT_SYMBOL_HOUR,
+  ! 分 dc_date_types#UNIT_SYMBOL_MIN, 秒 dc_date_types#UNIT_SYMBOL_SEC 
+  ! 無次元時間 dc_date_types#UNIT_SYMBOL_NONDIM
+  ! を与えることが可能です. 
   !
-  ! ˳ʤΤ *unit* ޤ *unit_symbol* 
-  ! Ϳ, ⤷ϰξȤͿʤ, 0.0 ֤ޤ.
+  ! これらに該当しないものを *unit* または *unit_symbol* 
+  ! に与えた場合, もしくは引数を両方とも与えない場合, 0.0 が返ります.
   !
   use dc_types, only: DP, TOKEN
   use dc_date_generic, only: EvalNondim, EvalSec, EvalMin, EvalHour, EvalDay, &
@@ -607,8 +607,8 @@ end function DCDiffTimeEvalByUnit
 
 !!$subroutine DCDateTimeEval0(time, mon, day, sec)
 !!$  !
-!!$  ! dc_date_types#DC_DATETIME ѿ *time* 
-!!$  !  *mon*,  *day*,  *sec* Ѵ֤.
+!!$  ! dc_date_types#DC_DATETIME 型変数の *time* を
+!!$  ! 月 *mon*, 日 *day*, 秒 *sec* に変換して返す.
 !!$  !
 !!$  use dc_types, only: DP
 !!$  use dc_date_types, only: DC_DATETIME, &
