@@ -1,31 +1,31 @@
 !
-!= gtool_history Fortran 77 ѥ󥿡ե
+!= gtool_history Fortran 77 用インターフェース
 !
 ! Authors::   Shin-ichi TAKEHIRO, Yasuhiro MORIKAWA
 ! Version::   $Id: hsaati.f90,v 1.2 2009-06-01 15:17:20 morikawa Exp $
-! Tag Name::  $Name: gtool5-20101228-1 $
+! Tag Name::  $Name:  $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
-!== ֥롼бɽ
+!== サブルーチン対応表
 !
 ! gtool_history_generic#HistoryAddAttr :: HSAATC,HSAATR,HSAATD,HSAATI
 !
 subroutine hsaati(vname, atname, value,i)
   !
-  !== ǽ
+  !== 機能
   !
-  ! ҥȥ꡼, ѿ°Ĥ.
+  ! ヒストリー, 変数に属性をつける.
   !
-  !== 
+  !== 備考
   !
-  ! VNAME ξˤϥҥȥ꡼ΥХ°Ȥư.
+  ! VNAME が空の場合にはヒストリーのグローバル属性として扱われる.
   !
   use gtool_history
-  character(len=*), intent(in):: vname ! ѿ̾
-  character(len=*), intent(in):: atname ! °̾
-  integer, intent(in):: value(i) ! ѿ
-  integer          :: i ! °μ
+  character(len=*), intent(in):: vname ! 変数名
+  character(len=*), intent(in):: atname ! 属性名
+  integer, intent(in):: value(i) ! 変数
+  integer          :: i ! 属性の次元数
 
   call HistoryAddAttr(vname, atname, value)
 
