@@ -1,27 +1,27 @@
 !
-!= gtool_history Fortran 77 ѥ󥿡ե
+!= gtool_history Fortran 77 用インターフェース
 !
 ! Authors::   Shin-ichi TAKEHIRO, Yasuhiro MORIKAWA
 ! Version::   $Id: hsp1r.f90,v 1.2 2009-06-01 15:17:19 morikawa Exp $
-! Tag Name::  $Name: gtool5-20101228-1 $
+! Tag Name::  $Name:  $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
-!== ֥롼бɽ
+!== サブルーチン対応表
 !
 ! gtool_history_generic#HistoryPut :: HSP1D, HSP2D, HSP3D, HSP1R, HSP2R, HSP3R
 !
 subroutine hsp1r(vname,var,i)
   !
-  !== ǽ
+  !== 機能
   !
-  ! ҥȥ꡼ѿϤ
+  ! ヒストリーに変数を出力する
   !
 
   use gtool_history
-  character(len=*) :: vname ! ѿ̾
-  real             :: var(i)  ! ѿ
-  integer          :: i ! Ƽ礭
+  character(len=*) :: vname ! 変数名
+  real             :: var(i)  ! 変数
+  integer          :: i ! 各次元の大きさ
 
   call HistoryPut(vname,var)
 
