@@ -1,18 +1,18 @@
-!= gtool_history_nmlinfo ⥸塼Υƥȥץ
+!= gtool_history_nmlinfo モジュールのテストプログラム
 !
 != Test program for "gtool_history_nmlinfo" 
 !
 ! Authors::   Yasuhiro MORIKAWA
 ! Version::   $Id: histnmlinfo.f90,v 1.2 2009-10-10 10:58:59 morikawa Exp $
-! Tag Name::  $Name: gtool5-20101228-1 $
+! Tag Name::  $Name:  $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2007. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
 ! <b>Note that Japanese and English are described in parallel.</b>
 !
-! gtool_history_nmlinfo ⥸塼ưƥȤԤΥץǤ.
-! ΥץबѥǤ뤳, Ӽ¹Ի
-! ץबｪλ뤳ȤǧƤ.
+! gtool_history_nmlinfo モジュールの動作テストを行うためのプログラムです.
+! このプログラムがコンパイルできること, および実行時に
+! プログラムが正常終了することを確認してください.
 !
 ! This program checks the operation of "gtool_history_nmlinfo" module.
 ! Confirm compilation and execution of this program.
@@ -41,11 +41,11 @@ program histnmlinfo
   implicit none
 
   !-------------------------------------------------------------------
-  !  ¸ɽ, ǥ̾, °̾
+  !  実験の表題, モデルの名称, 所属機関名
   !  Title of a experiment, name of model, sub-organ
   !-------------------------------------------------------------------
   character(*), parameter:: title = &
-    & 'gtool_history_nmlinfo_test $Name: gtool5-20101228-1 $ :: ' // &
+    & 'gtool_history_nmlinfo_test $Name:  $ :: ' // &
     & 'Test program of "gtool_history_nmlinfo" module'
   character(*), parameter:: source = &
     & 'gtool4 project ' // &
@@ -55,15 +55,15 @@ program histnmlinfo
 
 
   !-------------------------------------------------------------------
-  !  ѿ
+  !  作業変数
   !  Work variables
   !-------------------------------------------------------------------
-  type(ARGS):: arg            ! ޥɥ饤. 
+  type(ARGS):: arg            ! コマンドライン引数. 
                               ! Command line arguments
-  logical:: OPT_namelist      ! -N, --namelist ץ̵ͭ. 
+  logical:: OPT_namelist      ! -N, --namelist オプションの有無. 
                               ! Existence of '-N', '--namelist' option
   character(STRING):: VAL_namelist
-                              ! -N, --namelist ץ. 
+                              ! -N, --namelist オプションの値. 
                               ! Value of '-N', '--namelist' option
 
   type(GTHST_NMLINFO):: gthstnml00, gthstnml01, gthstnml02, gthstnml03, gthstnml04
@@ -73,42 +73,42 @@ program histnmlinfo
   integer:: i
   type(DC_DIFFTIME):: interval_time
   character(STRING):: file
-                              ! ҥȥǡΥե̾. 
+                              ! ヒストリデータのファイル名. 
                               ! History data filenames
   real(DP):: interval_value
-                              ! ҥȥǡνϴֳ֤ο. 
+                              ! ヒストリデータの出力間隔の数値. 
                               ! Numerical value for interval of history data output
   character(TOKEN):: interval_unit
-                              ! ҥȥǡνϴֳ֤ñ. 
+                              ! ヒストリデータの出力間隔の単位. 
                               ! Unit for interval of history data output
   character(TOKEN):: precision
-                              ! ҥȥǡ. 
+                              ! ヒストリデータの精度. 
                               ! Precision of history data
   logical:: time_average
-                              ! ϥǡʿѲե饰. 
+                              ! 出力データの平均化フラグ. 
                               ! Flag for time_average of output data.
   character(STRING):: fileprefix
-                              ! ҥȥǡΥե̾Ƭ. 
+                              ! ヒストリデータのファイル名の接頭詞. 
                               ! Prefixes of history data filenames
   character(STRING):: varnames
-                              ! ѿ̾ꥹ. 
+                              ! 変数名リスト. 
                               ! List of variables
   character(TOKEN), pointer:: varnames_array(:) =>null()
-                              ! ѿ̾ꥹ. 
+                              ! 変数名リスト. 
                               ! List of variables
 
   type(GT_HISTORY), pointer:: history00 =>null()
-                              ! gtool_history ⥸塼ѹ¤. 
+                              ! gtool_history モジュール用構造体. 
                               ! Derived type for "gtool_history" module
   character(TOKEN):: name
-                              ! ѿ̾. Variable identifier
+                              ! 変数名. Variable identifier
   logical:: invalid
 
 !!$  character(*), parameter:: subname = 'gtool_history_nmlinfo_test'
 continue
 
   !-------------------------------------------------------------------
-  !  ޥɥ饤ν
+  !  コマンドライン引数の処理
   !  Command line arguments handling
   !-------------------------------------------------------------------
   call DCArgsOpen( arg )
@@ -123,7 +123,7 @@ continue
   call DCArgsClose( arg )
 
   !-------------------------------------------------------------------
-  !  ܤν, λƥ
+  !  基本の初期設定, 終了処理テスト
   !  Basic initialization and termination test
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( gthstnml = gthstnml00 ) ! (out)
@@ -153,7 +153,7 @@ continue
 
 
   !-------------------------------------------------------------------
-  !  ʣ˴ؤ륨顼Υƥ
+  !  重複初期設定に関するエラー処理のテスト
   !  Error handling related to duplicated initialization test
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( gthstnml = gthstnml00 )  ! (inout)
@@ -166,7 +166,7 @@ continue
 
 
   !-------------------------------------------------------------------
-  !  λ˴ؤ륨顼Υƥ
+  !  終了処理に関するエラー処理のテスト
   !  Error handling related to termination test
   !-------------------------------------------------------------------
   call HstNmlInfoClose( gthstnml = gthstnml00, & ! (inout)
@@ -175,7 +175,7 @@ continue
     & answer = .true., check = err )
 
   !-------------------------------------------------------------------
-  !  λΥƥ
+  !  終了処理のテスト
   !  Termination test
   !-------------------------------------------------------------------
   call HstNmlInfoCreate(&
@@ -204,7 +204,7 @@ continue
   call HstNmlInfoClose( gthstnml = gthstnml01 ) ! (inout)
 
   !-------------------------------------------------------------------
-  !  ̵ͤ˴ؤ륨顼Υƥ
+  !  無効な値に関するエラー処理のテスト
   !  Error handling related to invalid values test
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( &
@@ -239,7 +239,7 @@ continue
   call HstNmlInfoClose( gthstnml = gthstnml02 ) ! (inout)
 
   !-------------------------------------------------------------------
-  !  ǡΥƥ
+  !  データ操作のテスト
   !  Data handling test
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( &
@@ -394,7 +394,7 @@ continue
   call HstNmlInfoClose( gthstnml = gthstnml03 ) ! (inout)
 
   !-------------------------------------------------------------------
-  !  ϥƥå䤤碌Υƥ
+  !  出力ステップ問い合わせのテスト
   !  Inquire output step test
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( &
@@ -458,7 +458,7 @@ continue
   call HstNmlInfoClose( gthstnml = gthstnml04 ) ! (inout)
 
   !-------------------------------------------------------------------
-  !  fileprefix ƥ
+  !  fileprefix テスト
   !  fileprefix test
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( &
@@ -523,7 +523,7 @@ continue
     & answer = 'foo/bar_', check = fileprefix )
 
   !-------------------------------------------------------------------
-  !  names ƥ
+  !  names テスト
   !  "names" test
   !-------------------------------------------------------------------
   call HstNmlInfoGetNames( gthstnml06, & ! (in)
@@ -577,7 +577,7 @@ continue
   call HstNmlInfoClose( gthstnml = gthstnml06 ) ! (inout)
 
   !-------------------------------------------------------------------
-  !  ResetDefault ƥ
+  !  ResetDefault テスト
   !  "ResetDefault" test
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( &
@@ -622,7 +622,7 @@ continue
   call HstNmlInfoClose( gthstnml = gthstnml07 ) ! (inout)
 
   !-------------------------------------------------------------------
-  !  ʣѿƥ
+  !  複数変数操作テスト
   !  Multiple variables handling test
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( &
@@ -667,7 +667,7 @@ continue
 
 
   !-------------------------------------------------------------------
-  !  ϥ⡼ɥƥȤ1 (Ūʽ)
+  !  出力モードテストその1 (基本的な出力)
   !  Output mode test part 1 (Basic outout)
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( &
@@ -846,7 +846,7 @@ continue
 
 
   !-------------------------------------------------------------------
-  !  ϥ⡼ɥƥȤ2 (ʣѿ1ĤΥե)
+  !  出力モードテストその2 (複数の変数を1つのファイルへ)
   !  Output mode test part 2 (Multi variables are output to one file)
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( &
@@ -1096,7 +1096,7 @@ continue
 
 
   !-------------------------------------------------------------------
-  !  ϥ⡼ɥƥȤ3 (Close Υ顼)
+  !  出力モードテストその3 (Close のエラー処理)
   !  Output mode test part 3 (error handling in Close)
   !-------------------------------------------------------------------
   call HstNmlInfoCreate( &
