@@ -2,7 +2,7 @@
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
 ! Version::   $Id: histtest.f90,v 1.6 2009-10-12 04:07:16 morikawa Exp $
-! Tag Name::  $Name: gtool5-20101228-1 $
+! Tag Name::  $Name:  $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2008. All rights reserved.
 ! License::   See COPYRIGHT[link:../COPYRIGHT]
 !
@@ -34,14 +34,14 @@ program histtest
   logical:: err, time_average_store
 continue
 
-  !----- ǥХå⡼ɤ -----
+  !----- デバッグモードへ -----
   call SetDebug
 
 !goto 1400
 
   !-----------------------------------------------------------------
-  !  HistoryCreate1 Ѥܽϥƥ
-  !    (Conventions  gt_version ϼư)
+  !  HistoryCreate1 を用いた基本出力テスト
+  !    (Conventions と gt_version は自動出力)
   !-----------------------------------------------------------------
   call HistoryPutLine( indent = '  ** PutLine test ** ' )
 
@@ -73,11 +73,11 @@ continue
 200 continue
 
   !-----------------------------------------------------------------
-  !  HistoryCreate1 Ѥϥƥ
-  !    ֤ gtool_history  TimeGoAhead ˤƿʤ롣
-  !    Ǥϻ֤򵤤ˤ HistoryPut ƤǤߤ롣
-  !    ξ硢HistoryCreate Ϥ origin  interval Ȥ롣
-  !    (gt_version Τߤưǽ)
+  !  HistoryCreate1 を用いた出力テスト
+  !    時間は gtool_history 内部の TimeGoAhead にて進める。
+  !    ここでは時間を気にせずただ HistoryPut を呼んでみる。
+  !    この場合、HistoryCreate に渡す origin と interval が使われる。
+  !    (gt_version のみを手動で出力)
   !-----------------------------------------------------------------
   call HistoryCreate(file='xhisttest/xhisttest2.nc', &
     & title='gtool_history test 2',                 &
@@ -102,12 +102,12 @@ continue
 !goto 1100
 
   !-----------------------------------------------------------------
-  !  HistoryCreate1 Ѥϥƥ
-  !    ֤ HistoryPut ˤͿ롣
-  !    (Conventions  gt_version ϼưǽ)
-  !    (origin  interval ϼư)
+  !  HistoryCreate1 を用いた出力テスト
+  !    時間は HistoryPut にて与える。
+  !    (Conventions と gt_version は手動で出力)
+  !    (origin と interval は自動設定)
   !-----------------------------------------------------------------
-  call HistoryCreate(file='xhisttest/xhisttest3.nc', & 
+  call HistoryCreate(file='xhisttest/xhisttest3.nc', &
     & title='gtool_history test 3', &
     & source='gtool5/Fortran library test kit', &
     & institution='GFD DennouClub', &
@@ -135,9 +135,9 @@ continue
   call HistoryClose
 
   !-----------------------------------------------------------------
-  !  HistoryCreate1 Ѥϥƥ
-  !    ֤ HistorySetTime ˤͿ롣
-  !    (Conventions Τߤưǽ)
+  !  HistoryCreate1 を用いた出力テスト
+  !    時間は HistorySetTime にて与える。
+  !    (Conventions のみを手動で出力)
   !-----------------------------------------------------------------
   call HistoryCreate(file='xhisttest/xhisttest4.nc', &
     & title='gtool_history test 4', &
@@ -169,11 +169,11 @@ continue
   call HistoryClose
 
   !-----------------------------------------------------------------
-  ! * HistoryCreate1 Ѥϥƥ
-  !   * Ū˰ɤͿ˽
-  !     GT_HISTORY ѿ
+  ! * HistoryCreate1 を用いた出力テスト
+  !   * 明示的に引数キーワードを与えずに出力
+  !     GT_HISTORY 変数を利用
   !
-  ! * HistoryCopy ˤ륳ԡΥƥ (GT_HISTORY ѿѤ)
+  ! * HistoryCopy によるコピーのテスト (GT_HISTORY 変数を利用した場合)
   !-----------------------------------------------------------------
   call HistoryCreate('xhisttest/xhisttest5.nc',    &
     & 'gtool_history test 5',                     &
@@ -210,8 +210,8 @@ continue
 
 
   !-----------------------------------------------------------------
-  ! * HistoryAddAttr Ѥϥƥ
-  ! * HistoryCopy ˤ륳ԡΥƥ (GT_HISTORY ѿѤʤ)
+  ! * HistoryAddAttr を用いた出力テスト
+  ! * HistoryCopy によるコピーのテスト (GT_HISTORY 変数を利用しない場合)
   !-----------------------------------------------------------------
   call HistoryCreate(file='xhisttest/xhisttest6.nc',       &
     & title='gtool_history test 6',                        &
@@ -230,7 +230,7 @@ continue
   call HistoryPut( 'lat', &
     & (/-70.0, -50.0, -30.0, -10.0, 10.0, 30.0, 50.0, 70.0/) )
 
-  call HistoryAddVariable( &                          ! ѿ
+  call HistoryAddVariable( &                          ! 変数定義
     & varname='zeta', dims=(/'lon','lat','t  '/)         , &
     & longname='vorticity', units='1/s', xtype='double'      )
 
@@ -253,117 +253,117 @@ continue
 
 
   !-----------------------------------------------------------------
-  !  HistoryPut  range ץưǧ
+  !  HistoryPut の range オプションの動作確認
   !-----------------------------------------------------------------
-  call HistoryCreate(file='xhisttest/xhisttest9.nc', &
-    & title='gtool_history test 9', &
-    & source='gtool5/Fortran library test kit', &
-    & institution='GFD DennouClub', &
-    & dims=StoA('x', 'l', 'time'), &
-    & dimsizes=(/3, 5, 0/), &
-    & longnames=StoA('eastward length', 'any parameter', 'time'), &
-    & units=StoA('m','1','s'), &
-    & origin=0.0, interval=0.0 ,&
-    & xtypes=StoA('float', 'int', 'float'))
-  call HistoryAddVariable('u', dims=StoA('x', 'l', 'time'), &
-    & longname='foo quantity', units='m/s')
-  call HistoryPut('x', (/10.0, 20.0, 30.0/))
-  call HistoryPut('l', (/1.0, 2.0, 3.0, 4.0, 5.0/))
-  call HistorySetTime(0.0)
-  do i = 1, 5
-    char = CPrintf("l=%d", i=(/i/))
-    call HistoryPut('u', &
-      & (/1.0 * real(i), 1.1 * real(i), 1.2 * real(i)/), range=char)
-  end do
-  call HistorySetTime(1.0)
-  do i = 1, 5
-    char = CPrintf("l=%d", i=(/i/))
-    call HistoryPut('u', &
-      & (/2.0 * real(i), 2.1 * real(i), 2.2 * real(i)/), range=char)
-  end do
-  call HistorySetTime( timed = 2.0_DP )
-  do i = 1, 5
-    char = CPrintf("l=%d", i=(/i/))
-    call HistoryPut('u', &
-      & (/3.0 * real(i), 3.1 * real(i), 3.2 * real(i)/), range=char)
-  end do
-  call HistoryPutLine( indent = '  ** PutLine test ** ' )
-  call HistoryClose
+!!  call HistoryCreate(file='xhisttest/xhisttest9.nc', &
+!!    & title='gtool_history test 9', &
+!!    & source='gtool5/Fortran library test kit', &
+!!    & institution='GFD DennouClub', &
+!!    & dims=StoA('x', 'l', 'time'), &
+!!    & dimsizes=(/3, 5, 0/), &
+!!    & longnames=StoA('eastward length', 'any parameter', 'time'), &
+!!    & units=StoA('m','1','s'), &
+!!    & origin=0.0, interval=0.0 ,&
+!!    & xtypes=StoA('float', 'int', 'float'))
+!!  call HistoryAddVariable('u', dims=StoA('x', 'l', 'time'), &
+!!    & longname='foo quantity', units='m/s')
+!!  call HistoryPut('x', (/10.0, 20.0, 30.0/))
+!!  call HistoryPut('l', (/1.0, 2.0, 3.0, 4.0, 5.0/))
+!!  call HistorySetTime(0.0)
+!!  do i = 1, 5
+!!    char = CPrintf("l=%d", i=(/i/))
+!!    call HistoryPut('u', &
+!!      & (/1.0 * real(i), 1.1 * real(i), 1.2 * real(i)/), range=char)
+!!  end do
+!!  call HistorySetTime(1.0)
+!!  do i = 1, 5
+!!    char = CPrintf("l=%d", i=(/i/))
+!!    call HistoryPut('u', &
+!!      & (/2.0 * real(i), 2.1 * real(i), 2.2 * real(i)/), range=char)
+!!  end do
+!!  call HistorySetTime( timed = 2.0_DP )
+!!  do i = 1, 5
+!!    char = CPrintf("l=%d", i=(/i/))
+!!    call HistoryPut('u', &
+!!      & (/3.0 * real(i), 3.1 * real(i), 3.2 * real(i)/), range=char)
+!!  end do
+!!  call HistoryPutLine( indent = '  ** PutLine test ** ' )
+!!  call HistoryClose
+!!
+!!1000 continue
+ !-----------------------------------------------------------------
+ !  HistoryPut の平均値出力の動作確認
+ !-----------------------------------------------------------------
+ call HistoryCreate(file='xhisttest/xhisttest10.nc', &
+   & title='gtool_history test 10', &
+   & source='gtool5/Fortran library test kit', &
+   & institution='GFD DennouClub', &
+   & dims=StoA('x', 'y', 'time'), &
+   & dimsizes=(/3, 2, 0/), &
+   & longnames=StoA('eastward length', 'northward length', 'time'), &
+   & units=StoA('m', 'm', 's'), &
+   & origin=0.0, interval=10.0  )
+ call HistoryAddVariable('Scalar', dims=(/''/), &
+   & longname='any quantity', units='m')
+ call HistoryAddVariable('Scalar2', dims=(/''/), &
+   & longname='any quantity', units='m', time_average=.true., &
+   & err = err )
+ call AssertEqual( 'average output error handling test 1-1', &
+   & answer = .true., check = err )
+ call HistoryAddVariable('Data', dims=StoA('x', 'y', 'time'), &
+   & longname='any quantity', units='m/s')
+ call HistoryAddVariable('DataAvr', dims=StoA('x', 'y', 'time'), &
+   & longname='average of any quantity', units='m/s', time_average=.true.)
+ call HistoryAddVariable('DataAvr2', dims=StoA('x', 'time'), &
+   & longname='average of any quantity', units='m/s', average=.true.)
+ call HistoryPut('x', (/1.0, 2.0, 3.0/))
+ call HistoryPut('y', (/1.0, 2.0, 3.0/))
+ call HistoryPut('Scalar', (/1.0/))
 
-1000 continue
-  !-----------------------------------------------------------------
-  !  HistoryPut ʿͽϤưǧ
-  !-----------------------------------------------------------------
-  call HistoryCreate(file='xhisttest/xhisttest10.nc', &
-    & title='gtool_history test 10', &
-    & source='gtool5/Fortran library test kit', &
-    & institution='GFD DennouClub', &
-    & dims=StoA('x', 'y', 'time'), &
-    & dimsizes=(/3, 2, 0/), &
-    & longnames=StoA('eastward length', 'northward length', 'time'), &
-    & units=StoA('m', 'm', 's'), &
-    & origin=0.0, interval=10.0  )
-  call HistoryAddVariable('Scalar', dims=(/''/), &
-    & longname='any quantity', units='m')
-  call HistoryAddVariable('Scalar2', dims=(/''/), &
-    & longname='any quantity', units='m', time_average=.true., &
-    & err = err )
-  call AssertEqual( 'average output error handling test 1-1', &
-    & answer = .true., check = err )
-  call HistoryAddVariable('Data', dims=StoA('x', 'y', 'time'), &
-    & longname='any quantity', units='m/s')
-  call HistoryAddVariable('DataAvr', dims=StoA('x', 'y', 'time'), &
-    & longname='average of any quantity', units='m/s', time_average=.true.)
-  call HistoryAddVariable('DataAvr2', dims=StoA('x', 'time'), &
-    & longname='average of any quantity', units='m/s', average=.true.)
-  call HistoryPut('x', (/1.0, 2.0, 3.0/))
-  call HistoryPut('y', (/1.0, 2.0, 3.0/))
-  call HistoryPut('Scalar', (/1.0/))
+ allocate( data2d(1:3,1:2) )
+ data2d = reshape( (/1.0, 2.0, 3.0, 4.0, 5.0, 6.0/), (/3,2/) )
+ call HistoryPut( varname = 'DataAvr', & ! (in)
+   & array = data2d, &                   ! (in)
+   & err = err )                         ! (out)
+ call AssertEqual( 'average output error handling test 2-1', &
+   & answer = .true., check = err )
 
-  allocate( data2d(1:3,1:2) )
-  data2d = reshape( (/1.0, 2.0, 3.0, 4.0, 5.0, 6.0/), (/3,2/) )
-  call HistoryPut( varname = 'DataAvr', & ! (in)
-    & array = data2d, &                   ! (in)
-    & err = err )                         ! (out)
-  call AssertEqual( 'average output error handling test 2-1', &
-    & answer = .true., check = err )
+ call HistoryPut( varname = 'Data', &    ! (in)
+   & array = (/1.0, 2.0, 3.0/), &        ! (in)
+   & range = 'y=1', &                    ! (in)
+   & time = 2.0, &                       ! (in)
+   & err = err )                         ! (out)
+ call AssertEqual( 'average output error handling test 2-2', &
+   & answer = .true., check = err )
 
-  call HistoryPut( varname = 'Data', &    ! (in)
-    & array = (/1.0, 2.0, 3.0/), &        ! (in)
-    & range = 'y=1', &                    ! (in)
-    & time = 2.0, &                       ! (in)
-    & err = err )                         ! (out)
-  call AssertEqual( 'average output error handling test 2-2', &
-    & answer = .true., check = err )
+ call HistoryPut( varname = 'DataAvr', & ! (in)
+   & array = (/1.0, 2.0, 3.0/), &        ! (in)
+   & time = 2.0, &                       ! (in)
+   & err = err )                         ! (out)
+ call AssertEqual( 'average output error handling test 2-3', &
+   & answer = .true., check = err )
 
-  call HistoryPut( varname = 'DataAvr', & ! (in)
-    & array = (/1.0, 2.0, 3.0/), &        ! (in)
-    & time = 2.0, &                       ! (in)
-    & err = err )                         ! (out)
-  call AssertEqual( 'average output error handling test 2-3', &
-    & answer = .true., check = err )
+ do i = 1, 35
+   data2d = data2d + 1.0
+   call HistoryPut( varname = 'Data', &
+     & array = data2d, time = real(i), quiet = .false. )
+   call HistoryPut( varname = 'DataAvr', &
+     & array = data2d, time = real(i), quiet = .false. )
+   call HistoryPut( varname = 'DataAvr2', &
+     & array = data2d(:,1), time = real(i), quiet = .false. )
+ end do
+ call HistoryPutLine( indent = '  ** PutLine test ** ' )
+ call HistoryClose
 
-  do i = 1, 35
-    data2d = data2d + 1.0
-    call HistoryPut( varname = 'Data', &
-      & array = data2d, time = real(i), quiet = .false. )
-    call HistoryPut( varname = 'DataAvr', &
-      & array = data2d, time = real(i), quiet = .false. )
-    call HistoryPut( varname = 'DataAvr2', &
-      & array = data2d(:,1), time = real(i), quiet = .false. )
-  end do
-  call HistoryPutLine( indent = '  ** PutLine test ** ' )
-  call HistoryClose
-
-  deallocate( data2d )
+ deallocate( data2d )
 
 
-!goto 9999
+! goto 9999
 
 1100 continue
 
   !-----------------------------------------------------------------
-  !  HistoryCreate3 Ѥܽϥƥ
+  !  HistoryCreate3 を用いた基本出力テスト
   !-----------------------------------------------------------------
   call DCDiffTimeCreate( origin1,    1.0, 'hr'  )
   call DCDiffTimeCreate( interval1,  1.0, 'hr'  )
@@ -395,8 +395,8 @@ continue
 1200 continue
 
   !-----------------------------------------------------------------
-  !  HistoryCreate3 Ѥܽϥƥ2
-  !    HistorySetTime Ѥ. 
+  !  HistoryCreate3 を用いた基本出力テスト2
+  !    HistorySetTime を使用する.
   !-----------------------------------------------------------------
   call DCDiffTimeCreate( origin1,    0.0001_DP, '1' )
   call DCDiffTimeCreate( interval1,  0.0100_DP, '1' )
@@ -428,8 +428,8 @@ continue
 1300 continue
 
   !-----------------------------------------------------------------
-  !  HistoryCreate3 Ѥܽϥƥ3
-  !    ֤ʴֳ֤ξʿѲ
+  !  HistoryCreate3 を用いた基本出力テスト3
+  !    時間が不等な間隔の場合の平均化処理
   !-----------------------------------------------------------------
   call DCDiffTimeCreate( origin1, min=0 )
   allocate( time_ary(1:10) )
@@ -486,7 +486,7 @@ continue
 1400 continue
 
   !-----------------------------------------------------------------
-  !  ʸǡν
+  !  文字型データの出力
   !-----------------------------------------------------------------
   call HistoryCreate(file='xhisttest/xhisttest14.nc', &
     & title='gtool_history test 14',                 &
